% function [Q] = InvKinematics(phi, theta, psi, x, y, z)
%clear all
% Input data is the robot's tool orientation and position (ZYZ Euler 
% Transformation. The script use inverse kinematics to calculate all 
% joints with respect to the position and orientation.

%% Input data
phi = 0;
theta = pi/2;
psi = 0;

O(1,:) = [0.9249;0.4775;0.2344];
O(2,:) = [0.9249;0.4775;0.1734];
O(3,:) = [0.9485;0.4775;0.1688];
O(4,:) = [1.0862;0.4775;0.1688];
O(5,:) = [1.1409;0.4775;0.1961];
O(6,:) = [1.0834;0.4571;0.3336];
O(7,:) = [0.9249;0.4571;0.3336];

o = O(1,:);

%% Dimensions IRB 4600
a1 = 0.175;
a2 = 0.900;
a3 = 0.175;
atool = 0.432157;

d1 = 0.495;
d4 = 0.960;
d6 = 0.135;
dtool = 0.18366;

%% DH Parameters
th    = [0; -pi/2; 0; 0; pi; 0];
d     = [d1; 0; 0; d4; 0; d6];
a     = [a1; a2; a3; 0; 0; 0];
alpha = [-pi/2; 0; -pi/2; pi/2; pi/2; 0];
                  
%% Euler Angle Transformation
R = [(cos(phi)*cos(theta)*cos(psi)-sin(phi)*sin(psi))   (-cos(phi)*cos(theta)*sin(psi)-sin(phi)*cos(psi))   (cos(phi)*sin(theta));
     (sin(phi)*cos(theta)*cos(psi)+cos(phi)*sin(psi))   (-sin(phi)*cos(theta)*sin(psi)+cos(phi)*cos(psi))   (sin(phi)*sin(theta));
     (-sin(theta)*cos(psi))                             (sin(theta)*sin(psi))                               (cos(theta))        ];

%% Tool Data
qt1 = 0.045;
qt2 = 0.023;
qt1 = -0.023;
qt2 = 0.045;
xt  = 0.432157;
yt  = 0.0117039;
zt  = 0.18366;

for i=1
    o = O(i,:)';
invDHMill = [cos(qt1) sin(qt1) 0 -xt; -sin(qt1) * cos(qt2) cos(qt1) * cos(qt2) -sin(qt2) -yt; -sin(qt1) * sin(qt2) cos(qt1) * sin(qt2) cos(qt2) -zt; 0 0 0 1;];

T = [  R    o ;
     0 0 0  1];

T5 = T*(invDHMill);
o6_1(1) = T5(1,4);
o6_1(2) = T5(2,4);
o6_1(3) = T5(3,4);

x = o6_1(1) - d(6)*T5(1,3);
y = o6_1(2) - d(6)*T5(2,3);
z = o6_1(3) - d(6)*T5(3,3);
R = T5(1:3,1:3);

% P0 = [x; y; z];

%% Solving Inverse Problem

% Theta 1
th1  = atan2(y,x);

% Theta 3
beta = sqrt(a(3).^2 + d(4).^2);
r    = sqrt((x-a(1).*cos(th1)).^2+(y-a(1).*sin(th1)).^2);
s    = z - d(1);
D    = (r.^2 + s.^2 - a(2).^2 - beta.^2)./(2*a(2)*beta);
th3 = atan2(sqrt(1-D.^2),D)-pi/2 + atan2(a(3),d(4));

% Theta 2
th2 = -atan2(s,r)+atan2(beta*sin(-th3-pi/2+atan2(a(3),d(4))),a(2)+beta*cos(-th3-pi/2+atan2(a(3),d(4))))+pi/2;

% DH joint variables
Q(1) = th1;
Q(2) = th2;
Q(3) = th3;

% Finding Euler angles corresponding to the rotation matrix
DH01 = [cos(Q(1)+th(1))       -sin(Q(1)+th(1))*cos(alpha(1))   sin(Q(1)+th(1))*sin(alpha(1))    a(1)*cos(Q(1)+th(1))   ;
        sin(Q(1)+th(1))        cos(Q(1)+th(1))*cos(alpha(1))  -cos(Q(1)+th(1))*sin(alpha(1))    a(1)*sin(Q(1)+th(1))   ;
              0                        sin(alpha(1))                   cos(alpha(1))                    d(1)           ;
              0                            0                               0                             1            ];

DH12 = [cos(Q(2)+th(2))       -sin(Q(2)+th(2))*cos(alpha(2))   sin(Q(2)+th(2))*sin(alpha(2))    a(2)*cos(Q(2)+th(2))   ;
        sin(Q(2)+th(2))        cos(Q(2)+th(2))*cos(alpha(2))  -cos(Q(2)+th(2))*sin(alpha(2))    a(2)*sin(Q(2)+th(2))   ;
              0                        sin(alpha(2))                   cos(alpha(2))                    d(2)           ;
              0                            0                               0                             1            ];

DH23 = [cos(Q(3)+th(3))       -sin(Q(3)+th(3))*cos(alpha(3))   sin(Q(3)+th(3))*sin(alpha(3))    a(3)*cos(Q(3)+th(3))   ;
        sin(Q(3)+th(3))        cos(Q(3)+th(3))*cos(alpha(3))  -cos(Q(3)+th(3))*sin(alpha(3))    a(3)*sin(Q(3)+th(3))   ;
              0                        sin(alpha(3))                   cos(alpha(3))                    d(3)           ;
              0                            0                               0                             1            ];
                         
T03 = DH01*DH12*DH23;
R03 = T03(1:3,1:3);
R36 = (R03')*R;

% E4 = [0 0 d(4) 1];
% P1 = T03*E4';

Q(5) = -atan2(sqrt(R36(1,3)^2+R36(2,3)^2),R36(3,3));
Q(4) = atan2(R36(2,3),R36(1,3));
Q(6) = atan2(R36(3,2),-R36(3,1))-pi;

%% Validation
DH_Matrix1 = [ cos(Q(1) + th(1))      -cos(alpha(1))*sin(Q(1) + th(1))     sin(alpha(1))*sin(Q(1) + th(1))     a(1)*cos(Q(1) + th(1));
               sin(Q(1) + th(1))       cos(alpha(1))*cos(Q(1) + th(1))    -sin(alpha(1))*cos(Q(1) + th(1))     a(1)*sin(Q(1) + th(1));
                         0               sin(alpha(1))                         cos(alpha(1))                             d(1)                ;
                         0                                     0                                0                                    1       ]; 


DH_Matrix2 = [ cos(Q(2) + th(2))      -cos(alpha(2))*sin(Q(2) + th(2))     sin(alpha(2))*sin(Q(2) + th(2))     a(2)*cos(Q(2) + th(2));
               sin(Q(2) + th(2))       cos(alpha(2))*cos(Q(2) + th(2))    -sin(alpha(2))*cos(Q(2) + th(2))     a(2)*sin(Q(2) + th(2));
                         0               sin(alpha(2))                         cos(alpha(2))                             d(2)                ;
                         0                                     0                                0                                    1       ]; 

DH_Matrix3 = [ cos(Q(3) + th(3))      -cos(alpha(3))*sin(Q(3) + th(3))     sin(alpha(3))*sin(Q(3) + th(3))     a(3)*cos(Q(3) + th(3));
               sin(Q(3) + th(3))       cos(alpha(3))*cos(Q(3) + th(3))    -sin(alpha(3))*cos(Q(3) + th(3))     a(3)*sin(Q(3) + th(3));
                         0               sin(alpha(3))                         cos(alpha(3))                             d(3)                ;
                         0                                     0                                0                                    1       ];

DH_Matrix4 = [ cos(Q(4) + th(4))      -cos(alpha(4))*sin(Q(4) + th(4))     sin(alpha(4))*sin(Q(4) + th(4))     a(4)*cos(Q(4) + th(4));
               sin(Q(4) + th(4))       cos(alpha(4))*cos(Q(4) + th(4))    -sin(alpha(4))*cos(Q(4) + th(4))     a(4)*sin(Q(4) + th(4));
                         0               sin(alpha(4))                         cos(alpha(4))                             d(4)                ;
                         0                                     0                                0                                    1       ]; 

DH_Matrix5 = [ cos(Q(5) + th(5))      -cos(alpha(5))*sin(Q(5) + th(5))     sin(alpha(5))*sin(Q(5) + th(5))     a(5)*cos(Q(5) + th(5));
               sin(Q(5) + th(5))       cos(alpha(5))*cos(Q(5) + th(5))    -sin(alpha(5))*cos(Q(5) + th(5))     a(5)*sin(Q(5) + th(5));
                         0               sin(alpha(5))                         cos(alpha(5))                             d(5)                ;
                         0                                     0                                0                                    1       ];  

DH_Matrix6 = [ cos(Q(6) + th(6))      -cos(alpha(6))*sin(Q(6) + th(6))     sin(alpha(6))*sin(Q(6) + th(6))     a(6)*cos(Q(6) + th(6));
               sin(Q(6) + th(6))       cos(alpha(6))*cos(Q(6) + th(6))    -sin(alpha(6))*cos(Q(6) + th(6))     a(6)*sin(Q(6) + th(6));
                         0               sin(alpha(6))                         cos(alpha(6))                             d(6)                ;
                         0                                     0                                0                                    1       ];  


DH  = DH_Matrix1;
P1 = DH(1:3,4);

x1 = DH*[0.1;0;0;1];
y1 = DH*[0;0.1;0;1];
z1 = DH*[0;0;0.1;1];
o1 = DH*[0;0;0;1];

DH  = DH_Matrix1*DH_Matrix2;
P2 = DH(1:3,4);

x2 = DH*[0.1;0;0;1];
y2 = DH*[0;0.1;0;1];
z2 = DH*[0;0;0.1;1];
o2 = DH*[0;0;0;1];

DH  = DH_Matrix1*DH_Matrix2*DH_Matrix3;
P3 = DH(1:3,4);

x3 = DH*[0.1;0;0;1];
y3 = DH*[0;0.1;0;1];
z3 = DH*[0;0;0.1;1];
o3 = DH*[0;0;0;1];

DH  = DH_Matrix1*DH_Matrix2*DH_Matrix3*DH_Matrix4;
P4 = DH(1:3,4);

x4 = DH*[0.1;0;0;1];
y4 = DH*[0;0.1;0;1];
z4 = DH*[0;0;0.1;1];
o4 = DH*[0;0;0;1];

DH  = DH_Matrix1*DH_Matrix2*DH_Matrix3*DH_Matrix4*DH_Matrix5;
P5 = DH(1:3,4);

x5 = DH*[0.1;0;0;1];
y5 = DH*[0;0.1;0;1];
z5 = DH*[0;0;0.1;1];
o5 = DH*[0;0;0;1];

DH  = DH_Matrix1*DH_Matrix2*DH_Matrix3*DH_Matrix4*DH_Matrix5*DH_Matrix6;
P6 = DH(1:3,4);

x6 = DH*[0.1;0;0;1];
y6 = DH*[0;0.1;0;1];
z6 = DH*[0;0;0.1;1];
o6 = DH*[0;0;0;1];


q1 = Q(1);
q2 = Q(2);
q3 = Q(3);
q4 = Q(4);
q5 = Q(5);
q6 = Q(6);
q=Q;

% DH07 = [(-sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q3) * cos(q4) * sin(q1) + (-sin(q3) * sin(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q5 + pi) * cos(q3) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) ^ 3 + (sin(q1) * sin(q6) * cos(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q4) * cos(q3) * (cos(q6) * sin(q1) + sin(q6) * cos(q1)) * cos(q5 + pi) - sin(q3) * ((-cos(q4) * sin(q1) - sin(q4) * cos(q1)) * sin(q6) + (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q6)) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + ((-sin(q3) * sin(q6) * cos(q5 + pi) * cos(q1) - cos(q6) * sin(q1) * sin(q5 + pi) * cos(q3) + sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * sin(q6)) * sin(pi / 0.2e1) ^ 2 - cos(q6) * sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q5 + pi) * cos(q1) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + ((-sin(q3) * sin(q5 + pi) * cos(q6) + sin(q4) * sin(q6) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + cos(q5 + pi) * cos(q3) * cos(q4) * cos(q6)) * cos(q1)) * cos(-q2 + pi / 0.2e1) + (-sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q4) * sin(q3) * sin(q1) + (sin(q6) * cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q3) * sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) ^ 3 + (sin(q1) * sin(q3) * sin(q6) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q3) * sin(q4) * (cos(q6) * sin(q1) + sin(q6) * cos(q1)) * cos(q5 + pi) + ((-cos(q4) * sin(q1) - sin(q4) * cos(q1)) * sin(q6) + (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q6)) * cos(q3) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + ((sin(q6) * cos(q1) * cos(q3) * cos(q5 + pi) - cos(q6) * sin(q1) * sin(q3) * sin(q5 + pi) - (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * sin(q6) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + cos(q6) * cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * cos(q1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + cos(q1) * ((cos(q3) * cos(q6) * sin(q5 + pi) + sin(q3) * sin(q4) * sin(q6)) * sin(pi / 0.2e1) ^ 2 + cos(q4) * sin(q3) * cos(q6) * cos(q5 + pi))) * sin(-q2 + pi / 0.2e1) + ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * sin(q6) * cos(pi / 0.2e1) ^ 2 + (-sin(q4) * sin(q6) + cos(q6) * (cos(q4) - 0.1e1)) * sin(q5 + pi) * cos(pi / 0.2e1) - sin(pi / 0.2e1) ^ 2 * cos(q4) * sin(q6) + sin(q4) * cos(q5 + pi) * cos(q6)) * sin(q1) * sin(pi / 0.2e1) ^ 2 (-cos(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q3) * cos(q4) * sin(q1) + (-cos(q6) * sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + sin(q1) * sin(q5 + pi) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) ^ 3 + (cos(q6) * sin(q1) * cos(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q4) * cos(q3) * (cos(q6) * cos(q1) - sin(q1) * sin(q6)) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * ((sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q6) + sin(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)))) * cos(pi / 0.2e1) ^ 2 + ((-cos(q6) * sin(q3) * cos(q1) * cos(q5 + pi) + sin(q1) * sin(q6) * sin(q5 + pi) * cos(q3) + sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * cos(q6)) * sin(pi / 0.2e1) ^ 2 + sin(q3) * sin(q6) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q5 + pi) * cos(q1) * cos(q3) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) - ((-sin(q4) * cos(q3) * cos(q6) - sin(q3) * sin(q6) * sin(q5 + pi)) * sin(pi / 0.2e1) ^ 2 + sin(q6) * cos(q3) * cos(q4) * cos(q5 + pi)) * cos(q1)) * cos(-q2 + pi / 0.2e1) + (-cos(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q4) * sin(q3) * sin(q1) + (cos(q6) * cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + sin(q1) * sin(q3) * sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) ^ 3 + (cos(q6) * sin(q1) * sin(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q3) * sin(q4) * (cos(q6) * cos(q1) - sin(q1) * sin(q6)) * cos(q5 + pi) - cos(q3) * sin(q5 + pi) * ((sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q6) + sin(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)))) * cos(pi / 0.2e1) ^ 2 + ((cos(q6) * cos(q1) * cos(q3) * cos(q5 + pi) + sin(q1) * sin(q3) * sin(q6) * sin(q5 + pi) - (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * cos(q3) * cos(q6)) * sin(pi / 0.2e1) ^ 2 - sin(q6) * cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * cos(q1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) - ((-sin(q3) * sin(q4) * cos(q6) + sin(q6) * cos(q3) * sin(q5 + pi)) * sin(pi / 0.2e1) ^ 2 + sin(q3) * sin(q6) * cos(q4) * cos(q5 + pi)) * cos(q1)) * sin(-q2 + pi / 0.2e1) + ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * cos(q6) * cos(pi / 0.2e1) ^ 2 - sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * (cos(q4) - 0.1e1)) * cos(pi / 0.2e1) - sin(pi / 0.2e1) ^ 2 * cos(q4) * cos(q6) - sin(q4) * sin(q6) * cos(q5 + pi)) * sin(q1) * sin(pi / 0.2e1) ^ 2 -((-sin(q1) * cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 3 + (sin(q3) * (sin(q4) * sin(q1) - cos(q1) * cos(q4)) * cos(q5 + pi) + sin(q1) * sin(q4) * sin(q5 + pi) * cos(q3) + sin(q3) * (sin(q4) * sin(q1) - cos(q1) * (cos(q4) - 0.1e1))) * cos(pi / 0.2e1) ^ 2 + (-sin(q1) * sin(pi / 0.2e1) ^ 2 * cos(q5 + pi) * cos(q3) - sin(q4) * cos(q1) * cos(q3) * cos(q5 + pi) + sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * sin(q5 + pi) - sin(q4) * cos(q1) * cos(q3)) * cos(pi / 0.2e1) - cos(q1) * (cos(q5 + pi) * sin(q3) * sin(pi / 0.2e1) ^ 2 + sin(q5 + pi) * cos(q3) * cos(q4))) * cos(-q2 + pi / 0.2e1) + (-sin(q1) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 3 + (-cos(q3) * (sin(q4) * sin(q1) - cos(q1) * cos(q4)) * cos(q5 + pi) + sin(q1) * sin(q3) * sin(q4) * sin(q5 + pi) - cos(q3) * (sin(q4) * sin(q1) - cos(q1) * (cos(q4) - 0.1e1))) * cos(pi / 0.2e1) ^ 2 + (-sin(q1) * sin(q3) * sin(pi / 0.2e1) ^ 2 * cos(q5 + pi) - sin(q3) * sin(q4) * cos(q1) * cos(q5 + pi) - cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * sin(q5 + pi) - sin(q3) * sin(q4) * cos(q1)) * cos(pi / 0.2e1) - cos(q1) * (-cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 2 + sin(q5 + pi) * cos(q4) * sin(q3))) * sin(-q2 + pi / 0.2e1) - sin(q1) * (-cos(pi / 0.2e1) ^ 3 - sin(pi / 0.2e1) ^ 2 * ((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * cos(pi / 0.2e1) + sin(q4) * sin(pi / 0.2e1) ^ 2 * sin(q5 + pi))) * sin(pi / 0.2e1) (-atool * sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q3) * cos(q4) * sin(q1) + (cos(q3) * sin(q1) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (dtool + d6) * sin(pi / 0.2e1) - atool * (sin(q3) * sin(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + sin(q1) * sin(q5 + pi) * cos(q3) * (cos(q4) * cos(q6) - sin(q4) * sin(q6)))) * cos(pi / 0.2e1) ^ 3 + (atool * sin(q6) * cos(q3) * sin(q1) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + (dtool + d6) * (sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q4) * sin(q5 + pi) * cos(q3) + sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) - atool * (sin(q4) * cos(q3) * (cos(q6) * sin(q1) + sin(q6) * cos(q1)) * cos(q5 + pi) + ((-sin(q6) * cos(q4) - sin(q4) * cos(q6)) * sin(q1) + cos(q1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q3) * sin(q5 + pi))) * cos(pi / 0.2e1) ^ 2 + (cos(q3) * sin(q1) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + atool * (-sin(q3) * sin(q6) * cos(q5 + pi) * cos(q1) - cos(q6) * sin(q1) * sin(q5 + pi) * cos(q3) + sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * sin(q6)) * sin(pi / 0.2e1) ^ 2 + (cos(q1) * cos(q3) * sin(q4) * (dtool + d6) * cos(q5 + pi) - sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (dtool + d6) * sin(q5 + pi) + (-d4 * sin(q1) + cos(q1) * sin(q4) * (dtool + d6)) * cos(q3)) * sin(pi / 0.2e1) - atool * cos(q6) * sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - atool * cos(q1) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)) * sin(q5 + pi) - sin(q1) * sin(q3) * a3) * cos(pi / 0.2e1) + cos(q1) * (sin(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + atool * (-sin(q3) * sin(q5 + pi) * cos(q6) + sin(q4) * sin(q6) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + (cos(q3) * cos(q4) * (dtool + d6) * sin(q5 + pi) - d4 * sin(q3)) * sin(pi / 0.2e1) + atool * cos(q4) * cos(q3) * cos(q5 + pi) * cos(q6) + a3 * cos(q3) + a2)) * cos(-q2 + pi / 0.2e1) + (-atool * sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q4) * sin(q3) * sin(q1) + (sin(q1) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (dtool + d6) * sin(pi / 0.2e1) + atool * (sin(q6) * cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q3) * sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6)))) * cos(pi / 0.2e1) ^ 3 + (atool * sin(q6) * sin(q1) * sin(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - (cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + sin(q1) * sin(q3) * sin(q4) * sin(q5 + pi) + cos(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * (dtool + d6) * sin(pi / 0.2e1) + atool * (-sin(q3) * sin(q4) * (cos(q6) * sin(q1) + sin(q6) * cos(q1)) * cos(q5 + pi) + ((-sin(q6) * cos(q4) - sin(q4) * cos(q6)) * sin(q1) + cos(q1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(q3) * sin(q5 + pi))) * cos(pi / 0.2e1) ^ 2 + (sin(q1) * sin(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 - atool * (-sin(q6) * cos(q1) * cos(q3) * cos(q5 + pi) + cos(q6) * sin(q1) * sin(q3) * sin(q5 + pi) + (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * sin(q6) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + (cos(q1) * sin(q3) * sin(q4) * (dtool + d6) * cos(q5 + pi) + cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (dtool + d6) * sin(q5 + pi) + sin(q3) * (-d4 * sin(q1) + cos(q1) * sin(q4) * (dtool + d6))) * sin(pi / 0.2e1) + atool * cos(q3) * cos(q6) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - atool * cos(q1) * sin(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)) * sin(q5 + pi) + sin(q1) * (a3 * cos(q3) + a2)) * cos(pi / 0.2e1) + cos(q1) * (-cos(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + atool * (cos(q3) * cos(q6) * sin(q5 + pi) + sin(q3) * sin(q4) * sin(q6)) * sin(pi / 0.2e1) ^ 2 + (cos(q4) * sin(q3) * (dtool + d6) * sin(q5 + pi) + cos(q3) * d4) * sin(pi / 0.2e1) + sin(q3) * (atool * cos(q4) * cos(q6) * cos(q5 + pi) + a3))) * sin(-q2 + pi / 0.2e1) - sin(q1) * sin(pi / 0.2e1) * (dtool + d6) * cos(pi / 0.2e1) ^ 3 + atool * sin(q6) * (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * sin(pi / 0.2e1) ^ 2 * sin(q1) * cos(pi / 0.2e1) ^ 2 + (-(dtool + d6) * ((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * sin(pi / 0.2e1) ^ 2 + atool * sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6)) * sin(pi / 0.2e1) - d4) * sin(pi / 0.2e1) * sin(q1) * cos(pi / 0.2e1) - atool * sin(q6) * cos(q4) * sin(q1) * sin(pi / 0.2e1) ^ 4 + sin(q1) * sin(q4) * sin(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + atool * cos(q6) * cos(q5 + pi) * sin(q1) * sin(q4) * sin(pi / 0.2e1) ^ 2 + a1 * cos(q1); (sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q1) * cos(q3) * cos(q4) + (-sin(q3) * sin(q6) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q5 + pi) * cos(q1) * cos(q3) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) ^ 3 + (-sin(q6) * cos(q1) * cos(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + sin(q4) * cos(q3) * (cos(q6) * cos(q1) - sin(q1) * sin(q6)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * ((sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q6) + sin(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)))) * cos(pi / 0.2e1) ^ 2 + ((-sin(q1) * sin(q3) * sin(q6) * cos(q5 + pi) + cos(q6) * sin(q5 + pi) * cos(q1) * cos(q3) + sin(q3) * sin(q6) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 + cos(q6) * sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q5 + pi) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + ((-sin(q3) * sin(q5 + pi) * cos(q6) + sin(q4) * sin(q6) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + cos(q5 + pi) * cos(q3) * cos(q4) * cos(q6)) * sin(q1)) * cos(-q2 + pi / 0.2e1) + (sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q1) * cos(q4) * sin(q3) + (sin(q6) * cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * cos(q1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) ^ 3 + (-sin(q3) * sin(q6) * cos(q1) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + sin(q3) * sin(q4) * (cos(q6) * cos(q1) - sin(q1) * sin(q6)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * ((sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q6) + sin(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)))) * cos(pi / 0.2e1) ^ 2 + ((sin(q6) * cos(q3) * sin(q1) * cos(q5 + pi) + cos(q6) * sin(q3) * sin(q5 + pi) * cos(q1) - sin(q6) * cos(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 - cos(q6) * cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q3) * sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + ((cos(q3) * cos(q6) * sin(q5 + pi) + sin(q3) * sin(q4) * sin(q6)) * sin(pi / 0.2e1) ^ 2 + cos(q4) * sin(q3) * cos(q6) * cos(q5 + pi)) * sin(q1)) * sin(-q2 + pi / 0.2e1) - ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * sin(q6) * cos(pi / 0.2e1) ^ 2 + (-sin(q4) * sin(q6) + cos(q6) * (cos(q4) - 0.1e1)) * sin(q5 + pi) * cos(pi / 0.2e1) - sin(pi / 0.2e1) ^ 2 * cos(q4) * sin(q6) + sin(q4) * cos(q5 + pi) * cos(q6)) * cos(q1) * sin(pi / 0.2e1) ^ 2 (cos(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q1) * cos(q3) * cos(q4) + (-cos(q6) * sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q5 + pi) * cos(q1) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) ^ 3 + (-cos(q6) * cos(q1) * cos(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q4) * cos(q3) * (cos(q6) * sin(q1) + sin(q6) * cos(q1)) * cos(q5 + pi) - sin(q3) * ((cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q6) - sin(q6) * (sin(q4) * cos(q1) + cos(q4) * sin(q1))) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + ((-cos(q6) * sin(q1) * sin(q3) * cos(q5 + pi) - sin(q6) * cos(q1) * cos(q3) * sin(q5 + pi) + sin(q3) * cos(q6) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 - sin(q3) * sin(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q5 + pi) * cos(q3) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) - ((-sin(q4) * cos(q3) * cos(q6) - sin(q3) * sin(q6) * sin(q5 + pi)) * sin(pi / 0.2e1) ^ 2 + sin(q6) * cos(q3) * cos(q4) * cos(q5 + pi)) * sin(q1)) * cos(-q2 + pi / 0.2e1) + (cos(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q1) * cos(q4) * sin(q3) + (cos(q6) * cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * cos(q1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) ^ 3 + (-cos(q6) * sin(q3) * cos(q1) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q3) * sin(q4) * (cos(q6) * sin(q1) + sin(q6) * cos(q1)) * cos(q5 + pi) + ((cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q6) - sin(q6) * (sin(q4) * cos(q1) + cos(q4) * sin(q1))) * cos(q3) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + ((cos(q6) * sin(q1) * cos(q3) * cos(q5 + pi) - sin(q3) * sin(q6) * cos(q1) * sin(q5 + pi) - cos(q3) * cos(q6) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 + sin(q6) * cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q3) * sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(pi / 0.2e1) - ((-sin(q3) * sin(q4) * cos(q6) + sin(q6) * cos(q3) * sin(q5 + pi)) * sin(pi / 0.2e1) ^ 2 + sin(q3) * sin(q6) * cos(q4) * cos(q5 + pi)) * sin(q1)) * sin(-q2 + pi / 0.2e1) - ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * cos(q6) * cos(pi / 0.2e1) ^ 2 - sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * (cos(q4) - 0.1e1)) * cos(pi / 0.2e1) - sin(pi / 0.2e1) ^ 2 * cos(q4) * cos(q6) - sin(q4) * sin(q6) * cos(q5 + pi)) * cos(q1) * sin(pi / 0.2e1) ^ 2 ((-cos(q1) * cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 3 + (sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q4) * sin(q5 + pi) * cos(q1) * cos(q3) + (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1)) * sin(q3)) * cos(pi / 0.2e1) ^ 2 + (-sin(pi / 0.2e1) ^ 2 * cos(q5 + pi) * cos(q1) * cos(q3) + sin(q1) * sin(q4) * cos(q3) * cos(q5 + pi) - sin(q3) * (sin(q4) * sin(q1) - cos(q1) * cos(q4)) * sin(q5 + pi) + sin(q4) * cos(q3) * sin(q1)) * cos(pi / 0.2e1) + sin(q1) * (cos(q5 + pi) * sin(q3) * sin(pi / 0.2e1) ^ 2 + sin(q5 + pi) * cos(q3) * cos(q4))) * cos(-q2 + pi / 0.2e1) + (-sin(q3) * cos(q1) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 3 + (-cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q3) * sin(q4) * sin(q5 + pi) * cos(q1) - (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1)) * cos(q3)) * cos(pi / 0.2e1) ^ 2 + (-sin(q3) * sin(pi / 0.2e1) ^ 2 * cos(q5 + pi) * cos(q1) + sin(q1) * sin(q3) * sin(q4) * cos(q5 + pi) + cos(q3) * (sin(q4) * sin(q1) - cos(q1) * cos(q4)) * sin(q5 + pi) + sin(q3) * sin(q4) * sin(q1)) * cos(pi / 0.2e1) + sin(q1) * (-cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 2 + sin(q5 + pi) * cos(q4) * sin(q3))) * sin(-q2 + pi / 0.2e1) - (-cos(pi / 0.2e1) ^ 3 - sin(pi / 0.2e1) ^ 2 * ((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * cos(pi / 0.2e1) + sin(q4) * sin(pi / 0.2e1) ^ 2 * sin(q5 + pi)) * cos(q1)) * sin(pi / 0.2e1) (atool * sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q1) * cos(q3) * cos(q4) + (-cos(q1) * cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (dtool + d6) * sin(pi / 0.2e1) + atool * (-sin(q3) * sin(q6) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q5 + pi) * cos(q1) * cos(q3) * (cos(q4) * cos(q6) - sin(q4) * sin(q6)))) * cos(pi / 0.2e1) ^ 3 + (-atool * cos(q1) * cos(q3) * sin(q6) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q4) * sin(q5 + pi) * cos(q1) * cos(q3) + (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1)) * sin(q3)) * (dtool + d6) * sin(pi / 0.2e1) + atool * (sin(q4) * cos(q3) * (cos(q6) * cos(q1) - sin(q1) * sin(q6)) * cos(q5 + pi) - sin(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(q1) + sin(q1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi))) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * cos(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + (-sin(q1) * sin(q3) * sin(q6) * cos(q5 + pi) + cos(q6) * sin(q5 + pi) * cos(q1) * cos(q3) + sin(q3) * sin(q6) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * atool * sin(pi / 0.2e1) ^ 2 + (cos(q3) * sin(q1) * sin(q4) * (dtool + d6) * cos(q5 + pi) + sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (dtool + d6) * sin(q5 + pi) + cos(q3) * (cos(q1) * d4 + sin(q1) * sin(q4) * (dtool + d6))) * sin(pi / 0.2e1) + atool * cos(q6) * sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - atool * cos(q3) * sin(q1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)) * sin(q5 + pi) + sin(q3) * a3 * cos(q1)) * cos(pi / 0.2e1) + sin(q1) * (sin(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + atool * (-sin(q3) * sin(q5 + pi) * cos(q6) + sin(q4) * sin(q6) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + (cos(q3) * cos(q4) * (dtool + d6) * sin(q5 + pi) - d4 * sin(q3)) * sin(pi / 0.2e1) + atool * cos(q4) * cos(q3) * cos(q5 + pi) * cos(q6) + a3 * cos(q3) + a2)) * cos(-q2 + pi / 0.2e1) + (atool * sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 4 * cos(q1) * cos(q4) * sin(q3) + (-sin(q3) * cos(q1) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (dtool + d6) * sin(pi / 0.2e1) + atool * (sin(q6) * cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * cos(q1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6)))) * cos(pi / 0.2e1) ^ 3 + (-atool * cos(q1) * sin(q3) * sin(q6) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - (dtool + d6) * (cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q4) * sin(q5 + pi) * cos(q1) + (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1)) * cos(q3)) * sin(pi / 0.2e1) + atool * (sin(q3) * sin(q4) * (cos(q6) * cos(q1) - sin(q1) * sin(q6)) * cos(q5 + pi) + cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(q1) + sin(q1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi))) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * sin(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 - atool * (-sin(q6) * cos(q3) * sin(q1) * cos(q5 + pi) - cos(q6) * sin(q3) * sin(q5 + pi) * cos(q1) + sin(q6) * cos(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 + (sin(q1) * sin(q3) * sin(q4) * (dtool + d6) * cos(q5 + pi) - cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (dtool + d6) * sin(q5 + pi) + sin(q3) * (cos(q1) * d4 + sin(q1) * sin(q4) * (dtool + d6))) * sin(pi / 0.2e1) - atool * cos(q3) * cos(q6) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - atool * sin(q1) * sin(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)) * sin(q5 + pi) - cos(q1) * (a3 * cos(q3) + a2)) * cos(pi / 0.2e1) + (-cos(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + atool * (cos(q3) * cos(q6) * sin(q5 + pi) + sin(q3) * sin(q4) * sin(q6)) * sin(pi / 0.2e1) ^ 2 + (cos(q4) * sin(q3) * (dtool + d6) * sin(q5 + pi) + cos(q3) * d4) * sin(pi / 0.2e1) + sin(q3) * (atool * cos(q4) * cos(q6) * cos(q5 + pi) + a3)) * sin(q1)) * sin(-q2 + pi / 0.2e1) + cos(q1) * sin(pi / 0.2e1) * (dtool + d6) * cos(pi / 0.2e1) ^ 3 - atool * cos(q1) * sin(q6) * (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * sin(pi / 0.2e1) ^ 2 * cos(pi / 0.2e1) ^ 2 - cos(q1) * (-(dtool + d6) * ((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * sin(pi / 0.2e1) ^ 2 + atool * sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6)) * sin(pi / 0.2e1) - d4) * sin(pi / 0.2e1) * cos(pi / 0.2e1) + atool * sin(q6) * cos(q4) * cos(q1) * sin(pi / 0.2e1) ^ 4 - cos(q1) * sin(q4) * sin(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 - atool * cos(q6) * cos(q5 + pi) * cos(q1) * sin(q4) * sin(pi / 0.2e1) ^ 2 + a1 * sin(q1); sin(pi / 0.2e1) * ((-cos(q5 + pi) * cos(pi / 0.2e1) ^ 3 * cos(q3) * cos(q4) * sin(q6) + (sin(q3) * sin(q4) * sin(q6) * cos(q5 + pi) + sin(q5 + pi) * cos(q3) * (sin(q4) * sin(q6) - cos(q4) * cos(q6))) * cos(pi / 0.2e1) ^ 2 + (-sin(q6) * cos(q3) * (cos(q5 + pi) - cos(q4) + 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q4) * cos(q5 + pi) * cos(q3) * cos(q6) + sin(q3) * sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + (-sin(q3) * sin(q4) * sin(q6) - cos(q3) * cos(q6) * sin(q5 + pi)) * sin(pi / 0.2e1) ^ 2 - cos(q4) * sin(q3) * cos(q6) * cos(q5 + pi)) * cos(-q2 + pi / 0.2e1) + (-cos(q5 + pi) * cos(pi / 0.2e1) ^ 3 * cos(q4) * sin(q6) * sin(q3) + (-sin(q4) * sin(q6) * cos(q3) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * (sin(q4) * sin(q6) - cos(q4) * cos(q6))) * cos(pi / 0.2e1) ^ 2 + (-sin(q3) * sin(q6) * (cos(q5 + pi) - cos(q4) + 0.1e1) * sin(pi / 0.2e1) ^ 2 - sin(q3) * sin(q4) * cos(q5 + pi) * cos(q6) - sin(q5 + pi) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + (-sin(q3) * sin(q5 + pi) * cos(q6) + sin(q4) * sin(q6) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + cos(q5 + pi) * cos(q3) * cos(q4) * cos(q6)) * sin(-q2 + pi / 0.2e1) + cos(pi / 0.2e1) * (-(-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * sin(q6) * cos(pi / 0.2e1) ^ 2 + (sin(q4) * sin(q6) - cos(q6) * (cos(q4) - 0.1e1)) * sin(q5 + pi) * cos(pi / 0.2e1) + sin(pi / 0.2e1) ^ 2 * cos(q4) * sin(q6) - sin(q4) * cos(q5 + pi) * cos(q6))) ((-cos(pi / 0.2e1) ^ 3 * cos(q5 + pi) * cos(q3) * cos(q4) * cos(q6) + (sin(q3) * sin(q4) * cos(q5 + pi) * cos(q6) + sin(q5 + pi) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) ^ 2 + (-cos(q3) * cos(q6) * (cos(q5 + pi) - cos(q4) + 0.1e1) * sin(pi / 0.2e1) ^ 2 + sin(q4) * sin(q6) * cos(q3) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * (sin(q4) * sin(q6) - cos(q4) * cos(q6))) * cos(pi / 0.2e1) + (-sin(q3) * sin(q4) * cos(q6) + sin(q6) * cos(q3) * sin(q5 + pi)) * sin(pi / 0.2e1) ^ 2 + sin(q3) * sin(q6) * cos(q4) * cos(q5 + pi)) * cos(-q2 + pi / 0.2e1) + (-sin(q3) * cos(pi / 0.2e1) ^ 3 * cos(q5 + pi) * cos(q4) * cos(q6) + (-sin(q4) * cos(q5 + pi) * cos(q3) * cos(q6) + sin(q3) * sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) ^ 2 + (-sin(q3) * cos(q6) * (cos(q5 + pi) - cos(q4) + 0.1e1) * sin(pi / 0.2e1) ^ 2 + sin(q3) * sin(q4) * sin(q6) * cos(q5 + pi) + sin(q5 + pi) * cos(q3) * (sin(q4) * sin(q6) - cos(q4) * cos(q6))) * cos(pi / 0.2e1) + (sin(q3) * sin(q6) * sin(q5 + pi) + sin(q4) * cos(q3) * cos(q6)) * sin(pi / 0.2e1) ^ 2 - sin(q6) * cos(q3) * cos(q4) * cos(q5 + pi)) * sin(-q2 + pi / 0.2e1) + cos(pi / 0.2e1) * (-(-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * cos(q6) * cos(pi / 0.2e1) ^ 2 + sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * (cos(q4) - 0.1e1)) * cos(pi / 0.2e1) + sin(pi / 0.2e1) ^ 2 * cos(q4) * cos(q6) + sin(q4) * sin(q6) * cos(q5 + pi))) * sin(pi / 0.2e1) sin(pi / 0.2e1) ^ 2 * (cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 2 + cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 2 - sin(q4) * (cos(q5 + pi) * sin(q3) + sin(q5 + pi) * cos(q3) + sin(q3)) * cos(pi / 0.2e1) - sin(q5 + pi) * cos(q4) * sin(q3)) * cos(-q2 + pi / 0.2e1) + (cos(q5 + pi) * sin(q3) * sin(pi / 0.2e1) ^ 2 + sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 2 + sin(q4) * (cos(q5 + pi) * cos(q3) - sin(q5 + pi) * sin(q3) + cos(q3)) * cos(pi / 0.2e1) + sin(q5 + pi) * cos(q3) * cos(q4)) * sin(pi / 0.2e1) ^ 2 * sin(-q2 + pi / 0.2e1) + cos(pi / 0.2e1) * ((((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * cos(pi / 0.2e1) - sin(q5 + pi) * sin(q4)) * sin(pi / 0.2e1) ^ 2 + cos(pi / 0.2e1) ^ 3) (sin(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 + (sin(q3) * sin(q6) * (cos(q4) - cos(q5 + pi) - 0.1e1) * cos(pi / 0.2e1) + sin(q4) * sin(q6) * cos(q3) - sin(q3) * sin(q5 + pi) * cos(q6)) * atool * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (dtool + d6) * cos(pi / 0.2e1) ^ 2 + sin(q4) * (cos(q5 + pi) * cos(q3) - sin(q5 + pi) * sin(q3) + cos(q3)) * (dtool + d6) * cos(pi / 0.2e1) + cos(q3) * cos(q4) * (dtool + d6) * sin(q5 + pi) - d4 * sin(q3)) * sin(pi / 0.2e1) - atool * sin(q3) * cos(q4) * cos(pi / 0.2e1) ^ 3 * cos(q5 + pi) * sin(q6) - (sin(q4) * sin(q6) * cos(q3) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * atool * cos(pi / 0.2e1) ^ 2 - atool * (sin(q3) * sin(q4) * cos(q5 + pi) * cos(q6) + sin(q5 + pi) * cos(q3) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + atool * cos(q4) * cos(q3) * cos(q5 + pi) * cos(q6) + a3 * cos(q3) + a2) * sin(pi / 0.2e1) * sin(-q2 + pi / 0.2e1) - (-cos(q3) * cos(q5 + pi) * (dtool + d6) * sin(pi / 0.2e1) ^ 3 - (cos(q3) * sin(q6) * (cos(q4) - cos(q5 + pi) - 0.1e1) * cos(pi / 0.2e1) - cos(q3) * cos(q6) * sin(q5 + pi) - sin(q3) * sin(q4) * sin(q6)) * atool * sin(pi / 0.2e1) ^ 2 + (-cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (dtool + d6) * cos(pi / 0.2e1) ^ 2 + sin(q4) * (cos(q5 + pi) * sin(q3) + sin(q5 + pi) * cos(q3) + sin(q3)) * (dtool + d6) * cos(pi / 0.2e1) + cos(q4) * sin(q3) * (dtool + d6) * sin(q5 + pi) + cos(q3) * d4) * sin(pi / 0.2e1) + sin(q6) * cos(q5 + pi) * cos(pi / 0.2e1) ^ 3 * cos(q3) * cos(q4) * atool + (-sin(q3) * sin(q4) * sin(q6) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * atool * cos(pi / 0.2e1) ^ 2 + atool * (sin(q4) * cos(q5 + pi) * cos(q3) * cos(q6) - sin(q3) * sin(q5 + pi) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(pi / 0.2e1) + sin(q3) * (atool * cos(q4) * cos(q6) * cos(q5 + pi) + a3)) * sin(pi / 0.2e1) * cos(-q2 + pi / 0.2e1) + sin(q6) * cos(pi / 0.2e1) * cos(q4) * sin(pi / 0.2e1) ^ 3 * atool + cos(pi / 0.2e1) * (((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * cos(pi / 0.2e1) - sin(q5 + pi) * sin(q4)) * (dtool + d6) * sin(pi / 0.2e1) ^ 2 - ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * sin(q6) * cos(pi / 0.2e1) ^ 2 + sin(q5 + pi) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6)) * cos(pi / 0.2e1) + sin(q4) * cos(q5 + pi) * cos(q6)) * cos(pi / 0.2e1) * atool * sin(pi / 0.2e1) + (dtool + d6) * cos(pi / 0.2e1) ^ 4 + cos(pi / 0.2e1) ^ 2 * d4 + d1; 0 0 0 1;];
DH07 = [(-cos(q3) * cos(q4) * sin(q1) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 4 + (-sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - cos(q3) * sin(q5 + pi) * sin(q1) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)))) * cos(pi / 0.2e1) ^ 3 + (cos(q3) * sin(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - cos(q3) * ((cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q1) + sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q4) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * (((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q1) - ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1))) * cos(pi / 0.2e1) ^ 2 + ((-sin(q3) * cos(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) - cos(q3) * sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) + (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 - sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi) * cos(q1)) * cos(pi / 0.2e1) + cos(q1) * ((-sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1) ^ 2 + cos(q5 + pi) * cos(q3) * cos(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)))) * cos(-q2 + pi / 0.2e1) + (-cos(q4) * sin(q1) * sin(q3) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 4 + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * sin(q1) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)))) * cos(pi / 0.2e1) ^ 3 + (sin(q1) * sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - ((cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q1) + sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q3) * sin(q4) * cos(q5 + pi) - sin(q5 + pi) * (((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q1) - ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1)) * cos(q3)) * cos(pi / 0.2e1) ^ 2 + ((cos(q3) * cos(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) - sin(q1) * sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) - (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q3) * sin(q5 + pi) * cos(q1)) * cos(pi / 0.2e1) + ((cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) + sin(q3) * sin(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1) ^ 2 + sin(q3) * cos(q5 + pi) * cos(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * cos(q1)) * sin(-q2 + pi / 0.2e1) + ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 2 + ((-sin(q4) * sin(q6) + cos(q6) * (cos(q4) - 0.1e1)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * (cos(q4) - 0.1e1))) * sin(q5 + pi) * cos(pi / 0.2e1) - cos(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(pi / 0.2e1) ^ 2 + sin(q4) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q1) * sin(pi / 0.2e1) ^ 2 (-cos(q3) * cos(q4) * sin(q1) * cos(qt2) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (sin(q1) * cos(q3) * sin(qt2) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) - cos(qt2) * (sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi) * sin(q1))) * cos(pi / 0.2e1) ^ 3 + (cos(q3) * sin(q1) * cos(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q4) * sin(q5 + pi) * cos(q3) + sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) - cos(qt2) * (cos(q3) * ((-cos(q6) * sin(qt1) - sin(q6) * cos(qt1)) * sin(q1) + cos(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q4) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q1) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(q1)))) * cos(pi / 0.2e1) ^ 2 + (sin(q1) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 * sin(qt2) + cos(qt2) * (-cos(q1) * sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q3) * sin(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 + (sin(q4) * cos(q1) * cos(q3) * cos(q5 + pi) - sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * sin(q5 + pi) + sin(q4) * cos(q1) * cos(q3)) * sin(qt2) * sin(pi / 0.2e1) - cos(qt2) * (-sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1))) * cos(pi / 0.2e1) - (-sin(qt2) * cos(q5 + pi) * sin(pi / 0.2e1) ^ 3 * sin(q3) - cos(qt2) * (sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(pi / 0.2e1) ^ 2 - cos(q3) * cos(q4) * sin(qt2) * sin(q5 + pi) * sin(pi / 0.2e1) + cos(q3) * cos(q4) * cos(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * cos(q1)) * cos(-q2 + pi / 0.2e1) + (-cos(q4) * sin(q1) * sin(q3) * cos(qt2) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (sin(q1) * sin(qt2) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) + (cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q3) * sin(q5 + pi) * sin(q1)) * cos(qt2)) * cos(pi / 0.2e1) ^ 3 + (sin(q1) * sin(q3) * cos(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - (cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + sin(q1) * sin(q3) * sin(q4) * sin(q5 + pi) + cos(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) - cos(qt2) * (sin(q3) * ((-cos(q6) * sin(qt1) - sin(q6) * cos(qt1)) * sin(q1) + cos(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q4) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q1) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(q1)))) * cos(pi / 0.2e1) ^ 2 + (sin(q1) * cos(q5 + pi) * sin(pi / 0.2e1) ^ 3 * sin(qt2) * sin(q3) - cos(qt2) * (-cos(q1) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) - sin(q1) * sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * sin(q4) * cos(q1) * cos(q5 + pi) + cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * sin(q5 + pi) + sin(q3) * sin(q4) * cos(q1)) * sin(qt2) * sin(pi / 0.2e1) - cos(qt2) * (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1))) * cos(pi / 0.2e1) - (sin(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * cos(qt2) * sin(pi / 0.2e1) ^ 2 - sin(pi / 0.2e1) * sin(qt2) * cos(q4) * sin(q5 + pi) * sin(q3) + cos(q4) * sin(q3) * cos(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * cos(q1)) * sin(-q2 + pi / 0.2e1) + (-sin(qt2) * cos(pi / 0.2e1) ^ 3 + (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(qt2) * sin(pi / 0.2e1) * cos(pi / 0.2e1) ^ 2 - sin(pi / 0.2e1) * (((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * sin(qt2) * sin(pi / 0.2e1) + sin(q5 + pi) * cos(qt2) * ((sin(q6) * cos(q4) + sin(q4) * cos(q6) - sin(q6)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6)))) * cos(pi / 0.2e1) - (cos(q4) * cos(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) ^ 2 - sin(q4) * sin(qt2) * sin(q5 + pi) * sin(pi / 0.2e1) + sin(q4) * cos(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1)) * sin(q1) * sin(pi / 0.2e1) (cos(q3) * cos(q4) * sin(q1) * sin(qt2) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (sin(q1) * cos(qt2) * cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) + (sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi) * sin(q1)) * sin(qt2)) * cos(pi / 0.2e1) ^ 3 + (-cos(q3) * sin(q1) * sin(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * (sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q4) * sin(q5 + pi) * cos(q3) + sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) + (cos(q3) * ((-cos(q6) * sin(qt1) - sin(q6) * cos(qt1)) * sin(q1) + cos(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q4) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q1) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(q1))) * sin(qt2)) * cos(pi / 0.2e1) ^ 2 + (sin(q1) * cos(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 - (-cos(q1) * sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q3) * sin(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * (sin(q4) * cos(q1) * cos(q3) * cos(q5 + pi) - sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * sin(q5 + pi) + sin(q4) * cos(q1) * cos(q3)) * sin(pi / 0.2e1) + (-sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1)) * sin(qt2)) * cos(pi / 0.2e1) + (cos(qt2) * cos(q5 + pi) * sin(q3) * sin(pi / 0.2e1) ^ 3 - (sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * cos(q3) * sin(pi / 0.2e1) * cos(q4) * sin(q5 + pi) + cos(q3) * cos(q4) * sin(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * cos(q1)) * cos(-q2 + pi / 0.2e1) + (cos(q4) * sin(q1) * sin(q3) * sin(qt2) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (sin(q1) * cos(qt2) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) - (cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q3) * sin(q5 + pi) * sin(q1)) * sin(qt2)) * cos(pi / 0.2e1) ^ 3 + (-sin(q1) * sin(q3) * sin(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - cos(qt2) * (cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + sin(q1) * sin(q3) * sin(q4) * sin(q5 + pi) + cos(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) + (sin(q3) * ((-cos(q6) * sin(qt1) - sin(q6) * cos(qt1)) * sin(q1) + cos(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q4) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q1) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(q1))) * sin(qt2)) * cos(pi / 0.2e1) ^ 2 + (sin(q1) * cos(qt2) * cos(q5 + pi) * sin(pi / 0.2e1) ^ 3 * sin(q3) + (-cos(q1) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) - sin(q1) * sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * (sin(q3) * sin(q4) * cos(q1) * cos(q5 + pi) + cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * sin(q5 + pi) + sin(q3) * sin(q4) * cos(q1)) * sin(pi / 0.2e1) + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1)) * sin(qt2)) * cos(pi / 0.2e1) + (-cos(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * sin(pi / 0.2e1) * cos(q4) * sin(q5 + pi) * sin(q3) + cos(q4) * sin(q3) * sin(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * cos(q1)) * sin(-q2 + pi / 0.2e1) - sin(q1) * (cos(qt2) * cos(pi / 0.2e1) ^ 3 + (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) * sin(qt2) * cos(pi / 0.2e1) ^ 2 - sin(pi / 0.2e1) * (-cos(qt2) * ((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * sin(pi / 0.2e1) + sin(q5 + pi) * ((sin(q6) * cos(q4) + sin(q4) * cos(q6) - sin(q6)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6))) * sin(qt2)) * cos(pi / 0.2e1) - (cos(q4) * sin(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) ^ 2 + sin(q4) * cos(qt2) * sin(q5 + pi) * sin(pi / 0.2e1) + sin(q4) * sin(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1)) * sin(pi / 0.2e1) (-cos(q3) * cos(q4) * sin(q1) * cos(q5 + pi) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) ^ 4 + (cos(q3) * sin(q1) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (zt + d6) * sin(pi / 0.2e1) - sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) - cos(q3) * sin(q5 + pi) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(q1)) * cos(pi / 0.2e1) ^ 3 + (cos(q3) * sin(q1) * (cos(q4) - cos(q5 + pi) - 0.1e1) * (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q1) * sin(q4) * sin(q5 + pi) * cos(q3) + sin(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * (zt + d6) * sin(pi / 0.2e1) - cos(q3) * sin(q4) * ((xt * cos(q6) - yt * sin(q6)) * sin(q1) + cos(q1) * (xt * sin(q6) + yt * cos(q6))) * cos(q5 + pi) - sin(q5 + pi) * (((-xt * sin(q6) - yt * cos(q6)) * cos(q4) - sin(q4) * (xt * cos(q6) - yt * sin(q6))) * sin(q1) + ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * cos(q1)) * sin(q3)) * cos(pi / 0.2e1) ^ 2 + (cos(q3) * sin(q1) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (-cos(q1) * sin(q3) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) - cos(q3) * sin(q1) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + (xt * sin(q6) + yt * cos(q6)) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1)) * sin(q3)) * sin(pi / 0.2e1) ^ 2 + (cos(q1) * cos(q3) * sin(q4) * (zt + d6) * cos(q5 + pi) - sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (zt + d6) * sin(q5 + pi) + (-d4 * sin(q1) + cos(q1) * sin(q4) * (zt + d6)) * cos(q3)) * sin(pi / 0.2e1) - sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) - ((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6))) * cos(q3) * cos(q1) * sin(q5 + pi) - sin(q1) * sin(q3) * a3) * cos(pi / 0.2e1) + cos(q1) * (sin(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (-sin(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + cos(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(pi / 0.2e1) ^ 2 + (cos(q3) * cos(q4) * (zt + d6) * sin(q5 + pi) - d4 * sin(q3)) * sin(pi / 0.2e1) + cos(q3) * cos(q4) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) + a3 * cos(q3) + a2)) * cos(-q2 + pi / 0.2e1) + (-cos(q4) * sin(q1) * sin(q3) * cos(q5 + pi) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) ^ 4 + (sin(q1) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (zt + d6) * sin(pi / 0.2e1) + cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) - sin(q5 + pi) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(q1) * sin(q3)) * cos(pi / 0.2e1) ^ 3 + (sin(q1) * sin(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 2 - (cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + sin(q1) * sin(q3) * sin(q4) * sin(q5 + pi) + cos(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * (zt + d6) * sin(pi / 0.2e1) - sin(q4) * ((xt * cos(q6) - yt * sin(q6)) * sin(q1) + cos(q1) * (xt * sin(q6) + yt * cos(q6))) * sin(q3) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (((-xt * sin(q6) - yt * cos(q6)) * cos(q4) - sin(q4) * (xt * cos(q6) - yt * sin(q6))) * sin(q1) + ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * cos(q1))) * cos(pi / 0.2e1) ^ 2 + (sin(q1) * sin(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (cos(q1) * cos(q3) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) - sin(q1) * sin(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) - (xt * sin(q6) + yt * cos(q6)) * cos(q3) * (-sin(q4) * sin(q1) + cos(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 + (cos(q1) * sin(q3) * sin(q4) * (zt + d6) * cos(q5 + pi) + cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (zt + d6) * sin(q5 + pi) + (-d4 * sin(q1) + cos(q1) * sin(q4) * (zt + d6)) * sin(q3)) * sin(pi / 0.2e1) + cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) - ((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6))) * cos(q1) * sin(q3) * sin(q5 + pi) + sin(q1) * (a3 * cos(q3) + a2)) * cos(pi / 0.2e1) + cos(q1) * (-cos(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (cos(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + sin(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(pi / 0.2e1) ^ 2 + (cos(q4) * sin(q3) * (zt + d6) * sin(q5 + pi) + cos(q3) * d4) * sin(pi / 0.2e1) + sin(q3) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) * cos(q5 + pi) + a3))) * sin(-q2 + pi / 0.2e1) - sin(q1) * sin(pi / 0.2e1) * (zt + d6) * cos(pi / 0.2e1) ^ 3 + (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 2 * (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * sin(q1) * cos(pi / 0.2e1) ^ 2 + sin(pi / 0.2e1) * sin(q1) * (-((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * (zt + d6) * sin(pi / 0.2e1) ^ 2 + ((xt * cos(q6) - yt * sin(q6)) * cos(q4) + (-xt * sin(q6) - yt * cos(q6)) * sin(q4) - xt * cos(q6) + yt * sin(q6)) * sin(q5 + pi) * sin(pi / 0.2e1) - d4) * cos(pi / 0.2e1) - cos(q4) * sin(q1) * (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 4 + sin(q1) * sin(q4) * sin(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + sin(q1) * sin(q4) * cos(q5 + pi) * (xt * cos(q6) - yt * sin(q6)) * sin(pi / 0.2e1) ^ 2 + a1 * cos(q1); (cos(q3) * cos(q4) * cos(q5 + pi) * cos(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 4 + (-sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1)) * cos(pi / 0.2e1) ^ 3 + (-cos(q3) * cos(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - ((-cos(q6) * cos(qt1) + sin(q6) * sin(qt1)) * cos(q1) + sin(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(q4) * cos(q3) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q1) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(q1))) * cos(pi / 0.2e1) ^ 2 + ((-sin(q1) * sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) + cos(q3) * cos(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) + (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 + sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi) * sin(q1)) * cos(pi / 0.2e1) + sin(q1) * ((-sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1) ^ 2 + cos(q5 + pi) * cos(q3) * cos(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)))) * cos(-q2 + pi / 0.2e1) + (cos(q4) * sin(q3) * cos(q5 + pi) * cos(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 4 + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1)) * cos(pi / 0.2e1) ^ 3 + (-sin(q3) * cos(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - ((-cos(q6) * cos(qt1) + sin(q6) * sin(qt1)) * cos(q1) + sin(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(q4) * sin(q3) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q1) + ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * cos(q1))) * cos(pi / 0.2e1) ^ 2 + ((cos(q3) * sin(q1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) + sin(q3) * cos(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) - (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1)) * cos(q3)) * sin(pi / 0.2e1) ^ 2 - cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q3) * sin(q5 + pi) * sin(q1)) * cos(pi / 0.2e1) + ((cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) + sin(q3) * sin(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1) ^ 2 + sin(q3) * cos(q5 + pi) * cos(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q1)) * sin(-q2 + pi / 0.2e1) - ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 2 + ((-sin(q4) * sin(q6) + cos(q6) * (cos(q4) - 0.1e1)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * (cos(q4) - 0.1e1))) * sin(q5 + pi) * cos(pi / 0.2e1) - cos(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(pi / 0.2e1) ^ 2 + sin(q4) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * cos(q1) * sin(pi / 0.2e1) ^ 2 (cos(q1) * cos(qt2) * cos(q5 + pi) * cos(q3) * cos(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (-cos(q1) * cos(q3) * sin(qt2) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) - (sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi) * cos(q1)) * cos(qt2)) * cos(pi / 0.2e1) ^ 3 + (-cos(q1) * cos(q3) * cos(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q4) * sin(q5 + pi) * cos(q1) * cos(q3) + sin(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) - cos(qt2) * (cos(q3) * ((cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q1) + sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q4) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q1)))) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 * sin(qt2) - (sin(q1) * sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q1) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * cos(qt2) * sin(pi / 0.2e1) ^ 2 + (sin(q1) * sin(q4) * cos(q3) * cos(q5 + pi) + sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * sin(q5 + pi) + sin(q4) * cos(q3) * sin(q1)) * sin(qt2) * sin(pi / 0.2e1) - cos(qt2) * (sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * sin(q1) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))))) * cos(pi / 0.2e1) - sin(q1) * (-sin(qt2) * cos(q5 + pi) * sin(pi / 0.2e1) ^ 3 * sin(q3) - cos(qt2) * (sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(pi / 0.2e1) ^ 2 - cos(q3) * cos(q4) * sin(qt2) * sin(q5 + pi) * sin(pi / 0.2e1) + cos(q3) * cos(q4) * cos(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)))) * cos(-q2 + pi / 0.2e1) + (cos(q1) * cos(q4) * sin(q3) * cos(qt2) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (-cos(q1) * sin(qt2) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) + cos(qt2) * (cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q3) * sin(q5 + pi) * cos(q1))) * cos(pi / 0.2e1) ^ 3 + (-cos(q1) * sin(q3) * cos(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - (cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q4) * sin(q5 + pi) * cos(q1) + cos(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) + (-((cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q1) + sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q3) * sin(q4) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q1))) * cos(qt2)) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * cos(q5 + pi) * sin(pi / 0.2e1) ^ 3 * sin(qt2) * sin(q3) - cos(qt2) * (-cos(q3) * sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q1) * sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) ^ 2 - (-sin(q1) * sin(q3) * sin(q4) * cos(q5 + pi) + cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * sin(q5 + pi) - sin(q3) * sin(q4) * sin(q1)) * sin(qt2) * sin(pi / 0.2e1) + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * sin(q1) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)))) * cos(qt2)) * cos(pi / 0.2e1) - (sin(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * cos(qt2) * sin(pi / 0.2e1) ^ 2 - sin(pi / 0.2e1) * sin(qt2) * cos(q4) * sin(q5 + pi) * sin(q3) + cos(q4) * sin(q3) * cos(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(q1)) * sin(-q2 + pi / 0.2e1) - (-sin(qt2) * cos(pi / 0.2e1) ^ 3 + (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(qt2) * sin(pi / 0.2e1) * cos(pi / 0.2e1) ^ 2 - sin(pi / 0.2e1) * (((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * sin(qt2) * sin(pi / 0.2e1) + sin(q5 + pi) * cos(qt2) * ((sin(q6) * cos(q4) + sin(q4) * cos(q6) - sin(q6)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6)))) * cos(pi / 0.2e1) - (cos(q4) * cos(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) ^ 2 - sin(q4) * sin(qt2) * sin(q5 + pi) * sin(pi / 0.2e1) + sin(q4) * cos(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1)) * sin(pi / 0.2e1) * cos(q1) (-cos(q1) * cos(q3) * cos(q4) * sin(qt2) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (-cos(q1) * cos(qt2) * cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) + (sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi) * cos(q1)) * sin(qt2)) * cos(pi / 0.2e1) ^ 3 + (cos(q1) * cos(q3) * sin(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * (sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q4) * sin(q5 + pi) * cos(q1) * cos(q3) + sin(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) + sin(qt2) * (cos(q3) * ((cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q1) + sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q4) * cos(q5 + pi) + sin(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q1)))) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * cos(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 + (sin(q1) * sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q1) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + (sin(q1) * sin(q4) * cos(q3) * cos(q5 + pi) + sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * sin(q5 + pi) + sin(q4) * cos(q3) * sin(q1)) * cos(qt2) * sin(pi / 0.2e1) + (sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * sin(q1) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)))) * sin(qt2)) * cos(pi / 0.2e1) + sin(q1) * (cos(qt2) * cos(q5 + pi) * sin(q3) * sin(pi / 0.2e1) ^ 3 - (sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * cos(q3) * sin(pi / 0.2e1) * cos(q4) * sin(q5 + pi) + cos(q3) * cos(q4) * sin(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)))) * cos(-q2 + pi / 0.2e1) + (-cos(q1) * cos(q4) * sin(q3) * sin(qt2) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 4 + (-cos(q1) * cos(qt2) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * sin(pi / 0.2e1) - (cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q3) * sin(q5 + pi) * cos(q1)) * sin(qt2)) * cos(pi / 0.2e1) ^ 3 + (cos(q1) * sin(q3) * sin(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * sin(pi / 0.2e1) ^ 2 - cos(qt2) * (cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q4) * sin(q5 + pi) * cos(q1) + cos(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) - (-((cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q1) + sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(q3) * sin(q4) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q1) - ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q1))) * sin(qt2)) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * cos(qt2) * cos(q5 + pi) * sin(pi / 0.2e1) ^ 3 * sin(q3) + (-cos(q3) * sin(q1) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q1) * sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 - cos(qt2) * (-sin(q1) * sin(q3) * sin(q4) * cos(q5 + pi) + cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * sin(q5 + pi) - sin(q3) * sin(q4) * sin(q1)) * sin(pi / 0.2e1) - (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * sin(q1) * ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)))) * sin(qt2)) * cos(pi / 0.2e1) + (-cos(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 + (cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * sin(pi / 0.2e1) * cos(q4) * sin(q5 + pi) * sin(q3) + cos(q4) * sin(q3) * sin(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(q1)) * sin(-q2 + pi / 0.2e1) + (cos(qt2) * cos(pi / 0.2e1) ^ 3 + (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) * sin(qt2) * cos(pi / 0.2e1) ^ 2 - sin(pi / 0.2e1) * (-cos(qt2) * ((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * sin(pi / 0.2e1) + sin(q5 + pi) * ((sin(q6) * cos(q4) + sin(q4) * cos(q6) - sin(q6)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6))) * sin(qt2)) * cos(pi / 0.2e1) - (cos(q4) * sin(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) ^ 2 + sin(q4) * cos(qt2) * sin(q5 + pi) * sin(pi / 0.2e1) + sin(q4) * sin(qt2) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1)) * sin(pi / 0.2e1) * cos(q1) (cos(q1) * cos(q3) * cos(q4) * cos(q5 + pi) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) ^ 4 + (-cos(q1) * cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (zt + d6) * sin(pi / 0.2e1) - sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * cos(q1)) * cos(pi / 0.2e1) ^ 3 + (-cos(q1) * cos(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) + sin(q4) * sin(q5 + pi) * cos(q1) * cos(q3) + sin(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * (zt + d6) * sin(pi / 0.2e1) + ((xt * cos(q6) - yt * sin(q6)) * cos(q1) - sin(q1) * (xt * sin(q6) + yt * cos(q6))) * cos(q3) * sin(q4) * cos(q5 + pi) - sin(q5 + pi) * sin(q3) * (((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6))) * cos(q1) + ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(q1))) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * cos(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (-sin(q1) * sin(q3) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) + cos(q1) * cos(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1)) * (xt * sin(q6) + yt * cos(q6)) * sin(q3)) * sin(pi / 0.2e1) ^ 2 + (cos(q3) * sin(q1) * sin(q4) * (zt + d6) * cos(q5 + pi) + sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (zt + d6) * sin(q5 + pi) + cos(q3) * (cos(q1) * d4 + sin(q1) * sin(q4) * (zt + d6))) * sin(pi / 0.2e1) + sin(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) - ((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6))) * cos(q3) * sin(q1) * sin(q5 + pi) + sin(q3) * a3 * cos(q1)) * cos(pi / 0.2e1) + sin(q1) * (sin(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (-sin(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + cos(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(pi / 0.2e1) ^ 2 + (cos(q3) * cos(q4) * (zt + d6) * sin(q5 + pi) - d4 * sin(q3)) * sin(pi / 0.2e1) + cos(q3) * cos(q4) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) + a3 * cos(q3) + a2)) * cos(-q2 + pi / 0.2e1) + (cos(q1) * cos(q4) * sin(q3) * cos(q5 + pi) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) ^ 4 + (-cos(q1) * sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (zt + d6) * sin(pi / 0.2e1) + cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) + sin(q5 + pi) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * cos(q1) * sin(q3)) * cos(pi / 0.2e1) ^ 3 + (-cos(q1) * sin(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 2 - (zt + d6) * (cos(q3) * (sin(q4) * cos(q1) + cos(q4) * sin(q1)) * cos(q5 + pi) - sin(q3) * sin(q4) * sin(q5 + pi) * cos(q1) + cos(q3) * (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1))) * sin(pi / 0.2e1) + ((xt * cos(q6) - yt * sin(q6)) * cos(q1) - sin(q1) * (xt * sin(q6) + yt * cos(q6))) * sin(q4) * sin(q3) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * (((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6))) * cos(q1) + ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(q1))) * cos(pi / 0.2e1) ^ 2 + (-cos(q1) * sin(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (cos(q3) * sin(q1) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) + cos(q1) * sin(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) - (sin(q4) * cos(q1) + sin(q1) * (cos(q4) - 0.1e1)) * (xt * sin(q6) + yt * cos(q6)) * cos(q3)) * sin(pi / 0.2e1) ^ 2 + (sin(q1) * sin(q3) * sin(q4) * (zt + d6) * cos(q5 + pi) - cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (zt + d6) * sin(q5 + pi) + sin(q3) * (cos(q1) * d4 + sin(q1) * sin(q4) * (zt + d6))) * sin(pi / 0.2e1) - cos(q3) * (cos(q1) * cos(q4) - sin(q4) * sin(q1)) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) - ((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6))) * sin(q1) * sin(q3) * sin(q5 + pi) - cos(q1) * (a3 * cos(q3) + a2)) * cos(pi / 0.2e1) + (-cos(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (cos(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + sin(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(pi / 0.2e1) ^ 2 + (cos(q4) * sin(q3) * (zt + d6) * sin(q5 + pi) + cos(q3) * d4) * sin(pi / 0.2e1) + sin(q3) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) * cos(q5 + pi) + a3)) * sin(q1)) * sin(-q2 + pi / 0.2e1) + cos(q1) * sin(pi / 0.2e1) * (zt + d6) * cos(pi / 0.2e1) ^ 3 - (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 2 * (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * cos(q1) * cos(pi / 0.2e1) ^ 2 - sin(pi / 0.2e1) * cos(q1) * (-((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * (zt + d6) * sin(pi / 0.2e1) ^ 2 + ((xt * cos(q6) - yt * sin(q6)) * cos(q4) + (-xt * sin(q6) - yt * cos(q6)) * sin(q4) - xt * cos(q6) + yt * sin(q6)) * sin(q5 + pi) * sin(pi / 0.2e1) - d4) * cos(pi / 0.2e1) + cos(q1) * cos(q4) * (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 4 - cos(q1) * sin(q4) * sin(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 - cos(q1) * sin(q4) * cos(q5 + pi) * (xt * cos(q6) - yt * sin(q6)) * sin(pi / 0.2e1) ^ 2 + a1 * sin(q1); -sin(pi / 0.2e1) * ((cos(q5 + pi) * cos(q3) * cos(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 3 + (-sin(q3) * sin(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) - cos(q3) * sin(q5 + pi) * ((sin(q4) * sin(q6) - cos(q4) * cos(q6)) * cos(qt1) + sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)))) * cos(pi / 0.2e1) ^ 2 + (cos(q3) * (cos(q5 + pi) - cos(q4) + 0.1e1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(pi / 0.2e1) ^ 2 + sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) - sin(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi)) * cos(pi / 0.2e1) + (cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) + sin(q3) * sin(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1) ^ 2 + sin(q3) * cos(q5 + pi) * cos(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * cos(-q2 + pi / 0.2e1) + (sin(q3) * cos(q5 + pi) * cos(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 3 + (sin(q4) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * ((sin(q4) * sin(q6) - cos(q4) * cos(q6)) * cos(qt1) + sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4)))) * cos(pi / 0.2e1) ^ 2 + (sin(q3) * (cos(q5 + pi) - cos(q4) + 0.1e1) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(pi / 0.2e1) ^ 2 + sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi)) * cos(pi / 0.2e1) + (sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(q5 + pi) - sin(q4) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1) ^ 2 - cos(q5 + pi) * cos(q3) * cos(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(-q2 + pi / 0.2e1) + ((-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(pi / 0.2e1) ^ 2 - sin(q5 + pi) * (((-cos(q4) + 0.1e1) * cos(q6) + sin(q4) * sin(q6)) * cos(qt1) + sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * (cos(q4) - 0.1e1))) * cos(pi / 0.2e1) - cos(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(pi / 0.2e1) ^ 2 + sin(q4) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * cos(pi / 0.2e1)) (sin(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 + cos(qt2) * (cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * cos(pi / 0.2e1) + cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(pi / 0.2e1) ^ 2 - sin(qt2) * (-cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 2 + sin(q4) * (cos(q5 + pi) * sin(q3) + sin(q5 + pi) * cos(q3) + sin(q3)) * cos(pi / 0.2e1) + sin(q5 + pi) * cos(q4) * sin(q3)) * sin(pi / 0.2e1) + (-cos(q4) * cos(q5 + pi) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 3 + (sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + (sin(q4) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) + ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q3) * sin(q5 + pi)) * cos(pi / 0.2e1) + cos(q4) * sin(q3) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * cos(qt2)) * sin(pi / 0.2e1) * cos(-q2 + pi / 0.2e1) - (-sin(qt2) * cos(q5 + pi) * sin(pi / 0.2e1) ^ 3 * sin(q3) - (sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * cos(pi / 0.2e1) + sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * cos(qt2) * sin(pi / 0.2e1) ^ 2 - sin(qt2) * (sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 2 - sin(q4) * (sin(q5 + pi) * sin(q3) - cos(q3) * cos(q5 + pi) - cos(q3)) * cos(pi / 0.2e1) + sin(q5 + pi) * cos(q3) * cos(q4)) * sin(pi / 0.2e1) + cos(qt2) * (cos(q4) * sin(q3) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 3 + (sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) - sin(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + (-sin(q3) * sin(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) + ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q3) * sin(q5 + pi)) * cos(pi / 0.2e1) + cos(q4) * cos(q5 + pi) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)))) * sin(pi / 0.2e1) * sin(-q2 + pi / 0.2e1) - cos(pi / 0.2e1) * (-cos(q4) * cos(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) ^ 3 - sin(qt2) * (((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * cos(pi / 0.2e1) - sin(q5 + pi) * sin(q4)) * sin(pi / 0.2e1) ^ 2 + ((cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * cos(pi / 0.2e1) ^ 2 - ((sin(q6) * cos(q4) + sin(q4) * cos(q6) - sin(q6)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6))) * sin(q5 + pi) * cos(pi / 0.2e1) - sin(q4) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * cos(qt2) * sin(pi / 0.2e1) - sin(qt2) * cos(pi / 0.2e1) ^ 3) -(-cos(qt2) * cos(q5 + pi) * cos(q3) * sin(pi / 0.2e1) ^ 3 + sin(qt2) * (cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * cos(pi / 0.2e1) + cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) - sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(pi / 0.2e1) ^ 2 + cos(qt2) * (-cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 2 + sin(q4) * (cos(q5 + pi) * sin(q3) + sin(q5 + pi) * cos(q3) + sin(q3)) * cos(pi / 0.2e1) + sin(q5 + pi) * cos(q4) * sin(q3)) * sin(pi / 0.2e1) + sin(qt2) * (-cos(q4) * cos(q5 + pi) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 3 + (sin(q3) * sin(q4) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) + cos(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + (sin(q4) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) + ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * sin(q3) * sin(q5 + pi)) * cos(pi / 0.2e1) + cos(q4) * sin(q3) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)))) * sin(pi / 0.2e1) * cos(-q2 + pi / 0.2e1) + (cos(qt2) * cos(q5 + pi) * sin(q3) * sin(pi / 0.2e1) ^ 3 - (sin(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (cos(q4) - cos(q5 + pi) - 0.1e1) * cos(pi / 0.2e1) + sin(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * sin(q5 + pi) + sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1))) * sin(qt2) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * cos(pi / 0.2e1) ^ 2 - sin(q4) * (sin(q5 + pi) * sin(q3) - cos(q3) * cos(q5 + pi) - cos(q3)) * cos(pi / 0.2e1) + sin(q5 + pi) * cos(q3) * cos(q4)) * cos(qt2) * sin(pi / 0.2e1) + sin(qt2) * (cos(q4) * sin(q3) * cos(q5 + pi) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(pi / 0.2e1) ^ 3 + (sin(q4) * cos(q3) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * cos(q5 + pi) - sin(q3) * ((sin(q4) * cos(q6) + sin(q6) * cos(q4)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6))) * sin(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + (-sin(q3) * sin(q4) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)) * cos(q5 + pi) + ((cos(q4) * cos(q6) - sin(q4) * sin(q6)) * cos(qt1) - sin(qt1) * (sin(q4) * cos(q6) + sin(q6) * cos(q4))) * cos(q3) * sin(q5 + pi)) * cos(pi / 0.2e1) + cos(q4) * cos(q5 + pi) * cos(q3) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1)))) * sin(pi / 0.2e1) * sin(-q2 + pi / 0.2e1) + cos(pi / 0.2e1) * (-cos(q4) * sin(qt2) * (cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * sin(pi / 0.2e1) ^ 3 + cos(qt2) * (((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * cos(pi / 0.2e1) - sin(q5 + pi) * sin(q4)) * sin(pi / 0.2e1) ^ 2 + sin(qt2) * ((cos(q6) * cos(qt1) - sin(q6) * sin(qt1)) * (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * cos(pi / 0.2e1) ^ 2 - ((sin(q6) * cos(q4) + sin(q4) * cos(q6) - sin(q6)) * cos(qt1) + sin(qt1) * (cos(q4) * cos(q6) - sin(q4) * sin(q6) - cos(q6))) * sin(q5 + pi) * cos(pi / 0.2e1) - sin(q4) * cos(q5 + pi) * (cos(q6) * sin(qt1) + sin(q6) * cos(qt1))) * sin(pi / 0.2e1) + cos(qt2) * cos(pi / 0.2e1) ^ 3) (sin(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (sin(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) - sin(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + cos(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(pi / 0.2e1) ^ 2 + (sin(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (zt + d6) * cos(pi / 0.2e1) ^ 2 + sin(q4) * (cos(q3) * cos(q5 + pi) - sin(q5 + pi) * sin(q3) + cos(q3)) * (zt + d6) * cos(pi / 0.2e1) + cos(q3) * cos(q4) * (zt + d6) * sin(q5 + pi) - d4 * sin(q3)) * sin(pi / 0.2e1) - cos(q4) * sin(q3) * cos(q5 + pi) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) ^ 3 + (-cos(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6)))) * cos(pi / 0.2e1) ^ 2 + (-sin(q3) * sin(q4) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) - cos(q3) * sin(q5 + pi) * ((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6)))) * cos(pi / 0.2e1) + cos(q3) * cos(q4) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) + a3 * cos(q3) + a2) * sin(pi / 0.2e1) * sin(-q2 + pi / 0.2e1) - sin(pi / 0.2e1) * (-cos(q3) * cos(q5 + pi) * (zt + d6) * sin(pi / 0.2e1) ^ 3 + (-cos(q3) * (cos(q4) - cos(q5 + pi) - 0.1e1) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) + cos(q3) * (xt * cos(q6) - yt * sin(q6)) * sin(q5 + pi) + sin(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6))) * sin(pi / 0.2e1) ^ 2 + (-cos(q3) * (cos(q5 + pi) * cos(q4) + cos(q4) - 0.1e1) * (zt + d6) * cos(pi / 0.2e1) ^ 2 + sin(q4) * (cos(q5 + pi) * sin(q3) + sin(q5 + pi) * cos(q3) + sin(q3)) * (zt + d6) * cos(pi / 0.2e1) + cos(q4) * sin(q3) * (zt + d6) * sin(q5 + pi) + cos(q3) * d4) * sin(pi / 0.2e1) + cos(q3) * cos(q4) * cos(q5 + pi) * (xt * sin(q6) + yt * cos(q6)) * cos(pi / 0.2e1) ^ 3 + (-sin(q3) * sin(q4) * (xt * sin(q6) + yt * cos(q6)) * cos(q5 + pi) + cos(q3) * sin(q5 + pi) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) - sin(q4) * (xt * sin(q6) + yt * cos(q6)))) * cos(pi / 0.2e1) ^ 2 + (cos(q3) * sin(q4) * (xt * cos(q6) - yt * sin(q6)) * cos(q5 + pi) - sin(q3) * sin(q5 + pi) * ((xt * sin(q6) + yt * cos(q6)) * cos(q4) + sin(q4) * (xt * cos(q6) - yt * sin(q6)))) * cos(pi / 0.2e1) + sin(q3) * ((xt * cos(q6) - yt * sin(q6)) * cos(q4) * cos(q5 + pi) + a3)) * cos(-q2 + pi / 0.2e1) + cos(q4) * cos(pi / 0.2e1) * (xt * sin(q6) + yt * cos(q6)) * sin(pi / 0.2e1) ^ 3 + (((cos(q4) - 0.1e1) * cos(q5 + pi) + cos(q4)) * cos(pi / 0.2e1) - sin(q5 + pi) * sin(q4)) * cos(pi / 0.2e1) * (zt + d6) * sin(pi / 0.2e1) ^ 2 - ((xt * sin(q6) + yt * cos(q6)) * (-0.1e1 + (cos(q4) - 0.1e1) * cos(q5 + pi)) * cos(pi / 0.2e1) ^ 2 + ((xt * cos(q6) - yt * sin(q6)) * cos(q4) + (-xt * sin(q6) - yt * cos(q6)) * sin(q4) - xt * cos(q6) + yt * sin(q6)) * sin(q5 + pi) * cos(pi / 0.2e1) + sin(q4) * cos(q5 + pi) * (xt * cos(q6) - yt * sin(q6))) * cos(pi / 0.2e1) * sin(pi / 0.2e1) + (zt + d6) * cos(pi / 0.2e1) ^ 4 + cos(pi / 0.2e1) ^ 2 * d4 + d1; 0 0 0 1;];

x7 = DH07*[0.1;0;0;1];
y7 = DH07*[0;0.1;0;1];
z7 = DH07*[0;0;0.1;1];o7 = [-0.960e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) - 0.135e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + sin(q(1)) * cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(4)) * zt - sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - 0.135e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - 0.135e0 * sin(q(5)) * sin(q(4)) * sin(q(1)) - 0.135e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) + 0.900e0 * cos(q(1)) * sin(q(2)) + 0.175e0 * cos(q(1)) - sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt1) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt1) * xt - sin(q(1)) * sin(q(5)) * cos(qt2) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(qt2) * sin(q(4)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt - sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt + cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt1) * sin(q(4)) * xt + sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * yt + sin(q(1)) * cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * zt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt1) * sin(q(4)) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * yt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * zt + cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt -0.135e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) - 0.960e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * sin(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt - cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * yt - cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * zt - cos(q(5)) * sin(q(6)) * sin(qt1) * cos(q(1)) * sin(q(4)) * xt + cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * yt + cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * zt + sin(q(1)) * cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(6)) * cos(qt1) * cos(q(1)) * sin(q(4)) * xt + 0.135e0 * sin(q(5)) * sin(q(4)) * cos(q(1)) - 0.135e0 * sin(q(5)) * cos(q(4)) * cos(q(3)) * sin(q(1)) * sin(q(2)) - 0.135e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) + 0.900e0 * sin(q(1)) * sin(q(2)) + sin(q(5)) * cos(qt2) * cos(q(1)) * sin(q(4)) * zt - sin(q(5)) * sin(qt2) * cos(q(1)) * sin(q(4)) * yt + cos(q(4)) * sin(q(6)) * cos(qt1) * cos(q(1)) * xt + cos(q(4)) * cos(q(6)) * sin(qt1) * cos(q(1)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt + 0.175e0 * sin(q(1)) cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt - 0.135e0 * cos(q(2)) * sin(q(3)) * cos(q(5)) - 0.135e0 * sin(q(2)) * cos(q(3)) * cos(q(5)) - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt - cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt - cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt + 0.175e0 * cos(q(2)) * cos(q(3)) - 0.175e0 * sin(q(2)) * sin(q(3)) - 0.960e0 * cos(q(2)) * sin(q(3)) - 0.960e0 * sin(q(2)) * cos(q(3)) - 0.135e0 * cos(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + 0.135e0 * sin(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - cos(q(5)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - sin(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt + sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + 0.900e0 * cos(q(2)) + 0.495e0];


P7 = o7(1:3)';
error_ToolTip = norm((P7 - o)')
error_TCP = norm(P6 - o6_1')

P0 = [0;0;0];

%% Plots
figure
sizetext = 8;
set(figure(1), 'Position', [50 400 500 650])
figure(1)
hold on
set(gca, 'FontSize', sizetext)
plot3(o(1), o(2), o(3),'k*','LineWidth',2), hold on
plot3(o6(1), o6(2), o6(3),'k*','LineWidth',2)
plot3([P1(1) P2(1) P3(1) P4(1) P5(1) P6(1)],...
      [P1(2) P2(2) P3(2) P4(2) P5(2) P6(2)],... 
      [P1(3) P2(3) P3(3) P4(3) P5(3) P6(3)],'k*','LineWidth',2);
plot3([P0(1) P1(1)], [P0(2) P1(2)], [P0(3) P1(3)],'k-','LineWidth',2);
plot3([P1(1) P2(1)], [P1(2) P2(2)], [P1(3) P2(3)],'k-','LineWidth',2);
plot3([P2(1) P3(1)], [P2(2) P3(2)], [P2(3) P3(3)],'k-','LineWidth',2);
plot3([P3(1) P4(1)], [P3(2) P4(2)], [P3(3) P4(3)],'k-','LineWidth',2);
plot3([P4(1) P5(1)], [P4(2) P5(2)], [P4(3) P5(3)],'k-','LineWidth',2);
plot3([P5(1) P6(1)], [P5(2) P6(2)], [P5(3) P6(3)],'k-','LineWidth',2);
robot = plot3([P6(1) P7(1)], [P6(2) P7(2)], [P6(3) P7(3)],'k-','LineWidth',2);

end


view(-211,28)
xlim([0 1.8]); ylim([-0.2 0.7]);zlim([-0.2 2])
grid on;
xlabel('X [m]'); ylabel('Y [m]'); zlabel('Z [m]');
axis equal

