% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
% % % ----------------------------------------------------------------% % %
%                      Script to compute error.                           %
% % % ----------------------------------------------------------------% % %
%   The goal is to find error along a trajectory by comparing robot and   %
%                        camera measurements.                             %
% % % ----------------------------------------------------------------% % %
% The error is the deviation from the nominal value. However, the time    %
% shift between camera and the robot is optimized to have minimum error   %
%                    between the camera and robot.                        %
% % % ----------------------------------------------------------------% % %
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %

close all
clear all


%% Force measurements
FC_1N  = dlmread('0507_1N_FC.txt','\t',13,1);
FC_5N = dlmread('0507_5N_FC.txt','\t',13,1);
FC_10N = dlmread('0507_10N_FC.txt','\t',13,1);
FC_25N = dlmread('0507_25N_FC.txt','\t',13,1);
FC_50N = dlmread('0507_50N_FC.txt','\t',13,1);

FC_1N_F_raw  = dlmread('0507_1N_FC_Filter.txt','\t',13,1);
FC_5N_F_raw = dlmread('0507_5N_FC_Filter.txt','\t',13,1);
FC_10N_F_raw = dlmread('0507_10N_FC_Filter.txt','\t',13,1);
FC_25N_F_raw = dlmread('0507_25N_FC_Filter.txt','\t',13,1);
FC_50N_F_raw = dlmread('0507_50N_FC_Filter.txt','\t',13,1);

h_force = 0.000504;   % Sampling time force
h_cam = 0.01;        % Sampling time camera system

% Without filter
FC_1N_new  = interp1(1:length(FC_1N),FC_1N,1:h_cam/h_force:length(FC_1N),'spline');
FC_5N_new = interp1(1:length(FC_5N),FC_5N,1:h_cam/h_force:length(FC_5N),'spline');
FC_10N_new = interp1(1:length(FC_10N),FC_10N,1:h_cam/h_force:length(FC_10N),'spline');
FC_25N_new = interp1(1:length(FC_25N),FC_25N,1:h_cam/h_force:length(FC_25N),'spline');
FC_50N_new = interp1(1:length(FC_50N),FC_50N,1:h_cam/h_force:length(FC_50N),'spline');

% With 5 Hz low pass filter from Test Signal Viewer
FC_1N_F  = interp1(1:length(FC_1N_F_raw),FC_1N_F_raw,1:h_cam/h_force:length(FC_1N_F_raw),'spline');
FC_5N_F  = interp1(1:length(FC_5N_F_raw),FC_5N_F_raw,1:h_cam/h_force:length(FC_5N_F_raw),'spline');
FC_10N_F = interp1(1:length(FC_10N_F_raw),FC_10N_F_raw,1:h_cam/h_force:length(FC_10N_F_raw),'spline');
FC_25N_F = interp1(1:length(FC_25N_F_raw),FC_25N_F_raw,1:h_cam/h_force:length(FC_25N_F_raw),'spline');
FC_50N_F = interp1(1:length(FC_50N_F_raw),FC_50N_F_raw,1:h_cam/h_force:length(FC_50N_F_raw),'spline');

%% Camera measurements
Cam =  [load('C:\Users\pettekve\Dropbox\_MASTER 2015\Master_Thesis_2015\Measement Script and Data\Camera Measurements\Petter_IRB4600_560_1N.mat')
    load('C:\Users\pettekve\Dropbox\_MASTER 2015\Master_Thesis_2015\Measement Script and Data\Camera Measurements\Petter_IRB4600_561_5N.mat')
    load('C:\Users\pettekve\Dropbox\_MASTER 2015\Master_Thesis_2015\Measement Script and Data\Camera Measurements\Petter_IRB4600_562_10N.mat')
    load('C:\Users\pettekve\Dropbox\_MASTER 2015\Master_Thesis_2015\Measement Script and Data\Camera Measurements\Petter_IRB4600_563_25N.mat')
    load('C:\Users\pettekve\Dropbox\_MASTER 2015\Master_Thesis_2015\Measement Script and Data\Camera Measurements\Petter_IRB4600_564_50N.mat')];

CamData_1 = Cam(1).DynTool(1:3,433:2886); % Select respective data for camera
CamData_2 = Cam(2).DynTool(1:3,398:2838); % Select respective data for camera
CamData_3 = Cam(3).DynTool(1:3,278:2676); % Select respective data for camera
CamData_4 = Cam(4).DynTool(1:3,278:2757); % Select respective data for camera
CamData_5 = Cam(5).DynTool(1:3,366:3151); % Select respective data for camera

%% Robot measurements
Rob.r1 = csvread('0507_3_1N.txt',1,0);
Rob.r2 = csvread('0507_2_5N.txt',1,0);
Rob.r3 = csvread('0507_2_10N.txt',1,0);
Rob.r4 = csvread('0507_2_25N.txt',1,0);
Rob.r5 = csvread('0507_2_50N.txt',1,0);

%% Load files
Parameters
GearRatio

%% Calculate end effector
ext_q.r1 = inv(g)*[Rob.r1(:,101) Rob.r1(:,118) Rob.r1(:,135) Rob.r1(:,152) Rob.r1(:,169) Rob.r1(:,186)]';
ext_q.r2 = inv(g)*[Rob.r2(:,101) Rob.r2(:,118) Rob.r2(:,135) Rob.r2(:,152) Rob.r2(:,169) Rob.r2(:,186)]';
ext_q.r3 = inv(g)*[Rob.r3(:,101) Rob.r3(:,118) Rob.r3(:,135) Rob.r3(:,152) Rob.r3(:,169) Rob.r3(:,186)]';
ext_q.r4 = inv(g)*[Rob.r4(:,101) Rob.r4(:,118) Rob.r4(:,135) Rob.r4(:,152) Rob.r4(:,169) Rob.r4(:,186)]';
ext_q.r5 = inv(g)*[Rob.r5(:,101) Rob.r5(:,118) Rob.r5(:,135) Rob.r5(:,152) Rob.r5(:,169) Rob.r5(:,186)]';

%% Calculate o7
for i = 1:1:length(Rob.r1)-1
    q = [ext_q.r1(1,i) ext_q.r1(2,i) ext_q.r1(3,i) ext_q.r1(4,i) ext_q.r1(5,i) ext_q.r1(6,i)];
    o7_1s(i,:) = [-0.960e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) - 0.135e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + sin(q(1)) * cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(4)) * zt - sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - 0.135e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - 0.135e0 * sin(q(5)) * sin(q(4)) * sin(q(1)) - 0.135e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) + 0.900e0 * cos(q(1)) * sin(q(2)) + 0.175e0 * cos(q(1)) - sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt1) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt1) * xt - sin(q(1)) * sin(q(5)) * cos(qt2) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(qt2) * sin(q(4)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt - sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt + cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt1) * sin(q(4)) * xt + sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * yt + sin(q(1)) * cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * zt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt1) * sin(q(4)) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * yt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * zt + cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt -0.135e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) - 0.960e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * sin(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt - cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * yt - cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * zt - cos(q(5)) * sin(q(6)) * sin(qt1) * cos(q(1)) * sin(q(4)) * xt + cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * yt + cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * zt + sin(q(1)) * cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(6)) * cos(qt1) * cos(q(1)) * sin(q(4)) * xt + 0.135e0 * sin(q(5)) * sin(q(4)) * cos(q(1)) - 0.135e0 * sin(q(5)) * cos(q(4)) * cos(q(3)) * sin(q(1)) * sin(q(2)) - 0.135e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) + 0.900e0 * sin(q(1)) * sin(q(2)) + sin(q(5)) * cos(qt2) * cos(q(1)) * sin(q(4)) * zt - sin(q(5)) * sin(qt2) * cos(q(1)) * sin(q(4)) * yt + cos(q(4)) * sin(q(6)) * cos(qt1) * cos(q(1)) * xt + cos(q(4)) * cos(q(6)) * sin(qt1) * cos(q(1)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt + 0.175e0 * sin(q(1)) cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt - 0.135e0 * cos(q(2)) * sin(q(3)) * cos(q(5)) - 0.135e0 * sin(q(2)) * cos(q(3)) * cos(q(5)) - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt - cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt - cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt + 0.175e0 * cos(q(2)) * cos(q(3)) - 0.175e0 * sin(q(2)) * sin(q(3)) - 0.960e0 * cos(q(2)) * sin(q(3)) - 0.960e0 * sin(q(2)) * cos(q(3)) - 0.135e0 * cos(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + 0.135e0 * sin(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - cos(q(5)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - sin(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt + sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + 0.900e0 * cos(q(2)) + 0.495e0];
end

for i = 1:1:length(Rob.r2)-1
    q = [ext_q.r2(1,i) ext_q.r2(2,i) ext_q.r2(3,i) ext_q.r2(4,i) ext_q.r2(5,i) ext_q.r2(6,i)];
    o7_2s(i,:) = [-0.960e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) - 0.135e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + sin(q(1)) * cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(4)) * zt - sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - 0.135e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - 0.135e0 * sin(q(5)) * sin(q(4)) * sin(q(1)) - 0.135e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) + 0.900e0 * cos(q(1)) * sin(q(2)) + 0.175e0 * cos(q(1)) - sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt1) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt1) * xt - sin(q(1)) * sin(q(5)) * cos(qt2) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(qt2) * sin(q(4)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt - sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt + cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt1) * sin(q(4)) * xt + sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * yt + sin(q(1)) * cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * zt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt1) * sin(q(4)) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * yt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * zt + cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt -0.135e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) - 0.960e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * sin(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt - cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * yt - cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * zt - cos(q(5)) * sin(q(6)) * sin(qt1) * cos(q(1)) * sin(q(4)) * xt + cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * yt + cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * zt + sin(q(1)) * cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(6)) * cos(qt1) * cos(q(1)) * sin(q(4)) * xt + 0.135e0 * sin(q(5)) * sin(q(4)) * cos(q(1)) - 0.135e0 * sin(q(5)) * cos(q(4)) * cos(q(3)) * sin(q(1)) * sin(q(2)) - 0.135e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) + 0.900e0 * sin(q(1)) * sin(q(2)) + sin(q(5)) * cos(qt2) * cos(q(1)) * sin(q(4)) * zt - sin(q(5)) * sin(qt2) * cos(q(1)) * sin(q(4)) * yt + cos(q(4)) * sin(q(6)) * cos(qt1) * cos(q(1)) * xt + cos(q(4)) * cos(q(6)) * sin(qt1) * cos(q(1)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt + 0.175e0 * sin(q(1)) cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt - 0.135e0 * cos(q(2)) * sin(q(3)) * cos(q(5)) - 0.135e0 * sin(q(2)) * cos(q(3)) * cos(q(5)) - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt - cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt - cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt + 0.175e0 * cos(q(2)) * cos(q(3)) - 0.175e0 * sin(q(2)) * sin(q(3)) - 0.960e0 * cos(q(2)) * sin(q(3)) - 0.960e0 * sin(q(2)) * cos(q(3)) - 0.135e0 * cos(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + 0.135e0 * sin(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - cos(q(5)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - sin(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt + sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + 0.900e0 * cos(q(2)) + 0.495e0];
end

for i = 1:1:length(Rob.r3)-1
    q = [ext_q.r3(1,i) ext_q.r3(2,i) ext_q.r3(3,i) ext_q.r3(4,i) ext_q.r3(5,i) ext_q.r3(6,i)];
    o7_3s(i,:) = [-0.960e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) - 0.135e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + sin(q(1)) * cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(4)) * zt - sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - 0.135e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - 0.135e0 * sin(q(5)) * sin(q(4)) * sin(q(1)) - 0.135e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) + 0.900e0 * cos(q(1)) * sin(q(2)) + 0.175e0 * cos(q(1)) - sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt1) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt1) * xt - sin(q(1)) * sin(q(5)) * cos(qt2) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(qt2) * sin(q(4)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt - sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt + cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt1) * sin(q(4)) * xt + sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * yt + sin(q(1)) * cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * zt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt1) * sin(q(4)) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * yt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * zt + cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt -0.135e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) - 0.960e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * sin(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt - cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * yt - cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * zt - cos(q(5)) * sin(q(6)) * sin(qt1) * cos(q(1)) * sin(q(4)) * xt + cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * yt + cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * zt + sin(q(1)) * cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(6)) * cos(qt1) * cos(q(1)) * sin(q(4)) * xt + 0.135e0 * sin(q(5)) * sin(q(4)) * cos(q(1)) - 0.135e0 * sin(q(5)) * cos(q(4)) * cos(q(3)) * sin(q(1)) * sin(q(2)) - 0.135e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) + 0.900e0 * sin(q(1)) * sin(q(2)) + sin(q(5)) * cos(qt2) * cos(q(1)) * sin(q(4)) * zt - sin(q(5)) * sin(qt2) * cos(q(1)) * sin(q(4)) * yt + cos(q(4)) * sin(q(6)) * cos(qt1) * cos(q(1)) * xt + cos(q(4)) * cos(q(6)) * sin(qt1) * cos(q(1)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt + 0.175e0 * sin(q(1)) cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt - 0.135e0 * cos(q(2)) * sin(q(3)) * cos(q(5)) - 0.135e0 * sin(q(2)) * cos(q(3)) * cos(q(5)) - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt - cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt - cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt + 0.175e0 * cos(q(2)) * cos(q(3)) - 0.175e0 * sin(q(2)) * sin(q(3)) - 0.960e0 * cos(q(2)) * sin(q(3)) - 0.960e0 * sin(q(2)) * cos(q(3)) - 0.135e0 * cos(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + 0.135e0 * sin(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - cos(q(5)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - sin(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt + sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + 0.900e0 * cos(q(2)) + 0.495e0];
end

for i = 1:1:length(Rob.r4)-1
    q = [ext_q.r4(1,i) ext_q.r4(2,i) ext_q.r4(3,i) ext_q.r4(4,i) ext_q.r4(5,i) ext_q.r4(6,i)];
    o7_4s(i,:) = [-0.960e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) - 0.135e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + sin(q(1)) * cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(4)) * zt - sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - 0.135e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - 0.135e0 * sin(q(5)) * sin(q(4)) * sin(q(1)) - 0.135e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) + 0.900e0 * cos(q(1)) * sin(q(2)) + 0.175e0 * cos(q(1)) - sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt1) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt1) * xt - sin(q(1)) * sin(q(5)) * cos(qt2) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(qt2) * sin(q(4)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt - sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt + cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt1) * sin(q(4)) * xt + sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * yt + sin(q(1)) * cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * zt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt1) * sin(q(4)) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * yt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * zt + cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt -0.135e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) - 0.960e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * sin(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt - cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * yt - cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * zt - cos(q(5)) * sin(q(6)) * sin(qt1) * cos(q(1)) * sin(q(4)) * xt + cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * yt + cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * zt + sin(q(1)) * cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(6)) * cos(qt1) * cos(q(1)) * sin(q(4)) * xt + 0.135e0 * sin(q(5)) * sin(q(4)) * cos(q(1)) - 0.135e0 * sin(q(5)) * cos(q(4)) * cos(q(3)) * sin(q(1)) * sin(q(2)) - 0.135e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) + 0.900e0 * sin(q(1)) * sin(q(2)) + sin(q(5)) * cos(qt2) * cos(q(1)) * sin(q(4)) * zt - sin(q(5)) * sin(qt2) * cos(q(1)) * sin(q(4)) * yt + cos(q(4)) * sin(q(6)) * cos(qt1) * cos(q(1)) * xt + cos(q(4)) * cos(q(6)) * sin(qt1) * cos(q(1)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt + 0.175e0 * sin(q(1)) cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt - 0.135e0 * cos(q(2)) * sin(q(3)) * cos(q(5)) - 0.135e0 * sin(q(2)) * cos(q(3)) * cos(q(5)) - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt - cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt - cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt + 0.175e0 * cos(q(2)) * cos(q(3)) - 0.175e0 * sin(q(2)) * sin(q(3)) - 0.960e0 * cos(q(2)) * sin(q(3)) - 0.960e0 * sin(q(2)) * cos(q(3)) - 0.135e0 * cos(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + 0.135e0 * sin(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - cos(q(5)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - sin(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt + sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + 0.900e0 * cos(q(2)) + 0.495e0];
end

for i = 1:1:length(Rob.r5)-1
    q = [ext_q.r5(1,i) ext_q.r5(2,i) ext_q.r5(3,i) ext_q.r5(4,i) ext_q.r5(5,i) ext_q.r5(6,i)];
    o7_5s(i,:) = [-0.960e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) - 0.135e0 * cos(q(1)) * sin(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + sin(q(1)) * cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(4)) * yt + sin(q(1)) * cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(4)) * zt - sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * xt + sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * xt - 0.135e0 * cos(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - 0.135e0 * sin(q(5)) * sin(q(4)) * sin(q(1)) - 0.135e0 * cos(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * cos(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) + 0.900e0 * cos(q(1)) * sin(q(2)) + 0.175e0 * cos(q(1)) - sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt1) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt1) * xt - sin(q(1)) * sin(q(5)) * cos(qt2) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(qt2) * sin(q(4)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt - sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt + sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * xt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * cos(q(1)) * sin(q(4)) * zt + cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * cos(q(1)) * sin(q(4)) * zt + sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt - sin(q(1)) * cos(q(5)) * cos(q(6)) * cos(qt1) * sin(q(4)) * xt + sin(q(1)) * cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * yt + sin(q(1)) * cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * zt + sin(q(1)) * cos(q(5)) * sin(q(6)) * sin(qt1) * sin(q(4)) * xt - sin(q(1)) * cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * yt - sin(q(1)) * cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * zt + cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * zt - cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * cos(q(1)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * cos(q(1)) * yt -0.135e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) * cos(q(5)) + 0.135e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) * cos(q(5)) - 0.960e0 * sin(q(1)) * sin(q(2)) * sin(q(3)) + 0.175e0 * sin(q(1)) * sin(q(2)) * cos(q(3)) + 0.960e0 * sin(q(1)) * cos(q(2)) * cos(q(3)) + 0.175e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(1)) * sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * zt + sin(q(1)) * cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt - cos(q(4)) * sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * yt - cos(q(4)) * sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * zt - cos(q(5)) * sin(q(6)) * sin(qt1) * cos(q(1)) * sin(q(4)) * xt + cos(q(4)) * cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * yt + cos(q(4)) * cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * zt + sin(q(1)) * cos(q(5)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt - sin(q(1)) * cos(q(5)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt - sin(q(1)) * cos(q(5)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(6)) * cos(qt1) * cos(q(1)) * sin(q(4)) * xt + 0.135e0 * sin(q(5)) * sin(q(4)) * cos(q(1)) - 0.135e0 * sin(q(5)) * cos(q(4)) * cos(q(3)) * sin(q(1)) * sin(q(2)) - 0.135e0 * sin(q(1)) * cos(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) + 0.900e0 * sin(q(1)) * sin(q(2)) + sin(q(5)) * cos(qt2) * cos(q(1)) * sin(q(4)) * zt - sin(q(5)) * sin(qt2) * cos(q(1)) * sin(q(4)) * yt + cos(q(4)) * sin(q(6)) * cos(qt1) * cos(q(1)) * xt + cos(q(4)) * cos(q(6)) * sin(qt1) * cos(q(1)) * xt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt + sin(q(1)) * cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt - sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * cos(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(1)) * sin(q(4)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - sin(q(1)) * sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + sin(q(1)) * sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + sin(q(1)) * sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * sin(q(4)) * xt + sin(q(1)) * sin(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * yt - cos(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(1)) * sin(q(4)) * zt + sin(q(1)) * sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt + 0.175e0 * sin(q(1)) cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * yt - cos(q(5)) * cos(q(4)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * yt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * zt - 0.135e0 * cos(q(2)) * sin(q(3)) * cos(q(5)) - 0.135e0 * sin(q(2)) * cos(q(3)) * cos(q(5)) - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * cos(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * cos(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * cos(q(2)) * zt - cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * xt + cos(q(5)) * cos(q(4)) * cos(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * xt - sin(q(6)) * cos(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt + sin(q(6)) * cos(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt - sin(q(6)) * sin(qt2) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt + sin(q(6)) * sin(qt2) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * yt - sin(q(5)) * sin(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * sin(q(2)) * zt - sin(q(5)) * sin(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * xt - cos(q(5)) * cos(q(4)) * sin(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * xt + cos(q(6)) * cos(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * yt - cos(q(6)) * cos(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * yt + cos(q(6)) * sin(qt2) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * zt - cos(q(6)) * sin(qt2) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * zt + 0.175e0 * cos(q(2)) * cos(q(3)) - 0.175e0 * sin(q(2)) * sin(q(3)) - 0.960e0 * cos(q(2)) * sin(q(3)) - 0.960e0 * sin(q(2)) * cos(q(3)) - 0.135e0 * cos(q(2)) * cos(q(3)) * sin(q(5)) * cos(q(4)) + 0.135e0 * sin(q(2)) * sin(q(3)) * sin(q(5)) * cos(q(4)) - cos(q(5)) * cos(qt2) * cos(q(3)) * sin(q(2)) * zt - cos(q(5)) * cos(qt2) * sin(q(3)) * cos(q(2)) * zt + cos(q(5)) * sin(qt2) * cos(q(3)) * sin(q(2)) * yt + cos(q(5)) * sin(qt2) * sin(q(3)) * cos(q(2)) * yt - sin(q(5)) * cos(q(4)) * sin(qt2) * sin(q(3)) * sin(q(2)) * yt + sin(q(5)) * cos(q(6)) * cos(qt1) * cos(q(3)) * sin(q(2)) * xt + sin(q(5)) * cos(q(6)) * cos(qt1) * sin(q(3)) * cos(q(2)) * xt + sin(q(6)) * cos(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - sin(q(6)) * cos(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * cos(q(3)) * sin(q(2)) * xt - sin(q(5)) * sin(q(6)) * sin(qt1) * sin(q(3)) * cos(q(2)) * xt + cos(q(6)) * sin(qt1) * cos(q(3)) * cos(q(2)) * sin(q(4)) * xt - cos(q(6)) * sin(qt1) * sin(q(3)) * sin(q(2)) * sin(q(4)) * xt - sin(q(5)) * cos(q(4)) * cos(qt2) * cos(q(3)) * cos(q(2)) * zt + sin(q(5)) * cos(q(4)) * cos(qt2) * sin(q(3)) * sin(q(2)) * zt + sin(q(5)) * cos(q(4)) * sin(qt2) * cos(q(3)) * cos(q(2)) * yt + 0.900e0 * cos(q(2)) + 0.495e0];
end

%% Sample down robot data to match camera
[Cam_Ext_1, o7_1] = Sampling_Rob(o7_1s, CamData_1, 0.004032);
[Cam_Ext_2, o7_2] = Sampling_Rob(o7_2s, CamData_2, 0.004032);
[Cam_Ext_3, o7_3] = Sampling_Rob(o7_3s, CamData_3, 0.004032);
[Cam_Ext_4, o7_4] = Sampling_Rob(o7_4s, CamData_4, 0.004032);
[Cam_Ext_5, o7_5] = Sampling_Rob(o7_5s, CamData_5, 0.004032);

%% Compute Deviation between camera and robot
Error_1 = Cam_Ext_1-o7_1;
Error_2 = Cam_Ext_2-o7_2;
Error_3 = Cam_Ext_3-o7_3;
Error_4 = Cam_Ext_4-o7_4;
Error_5 = Cam_Ext_5-o7_5;



